hemoServices
.factory('CalcDataPe', function() {
  return {
    startState: "app.calculator_pe",
    name: "Wells' Criteria for Pulmonary Embolism",
    slug: "pe",
    type: "checkbox",
    reference: "Wells PS, Anderson DR, Rodger M, et. al “Derivation of a simple clinical model to categorize patients probability of pulmonary embolism: increasing the models utility with the SimpliRED D-dimer.” <em>Thromb Haemost</em> 83.3 (2000):416-20.",
    preText: "<p>The Wells™ Criteria risk stratifies patients for pulmonary embolism (PE), and has been validated in both inpatient and emergency department settings. Its score is often used in conjunctiion with d-dimer testing to evaluate for PE.</p>",
    postText: "",
    rangeThresholds: [
      {2: "low"},
      {7: "moderate"},
      {100: "high"}
    ],
    rangeDescriptions: {
      low: "Low risk group: 1.3% chance of PE in an ED population. Another study assigned scores below 4 as 'PE Unlikely' and had a 3% incidence of PE.",
      moderate: "Moderate risk group: 16.2% chance of PE in an ED population. Another study assigned scores > 4 as 'PE Likely' and had a 28% incidence of PE.",
      high: "High risk group: 40.6% chance of PE in an ED population. Another study assigned scores > 4 as 'PE Likely' and had a 28% incidence of PE."
    },
    questions: [
      {
        title: "Check all that apply",
        total: 0,
        options: [
          {
            label: "Clinical Signs and Symptoms of DVT",
            value: 3,
            isSelected: false
          },
          {
            label: "PE Is #1 Diagnosis, or Equally Likely",
            value: 3,
            isSelected: false
          },
          {
            label: "Heart Rate > 100",
            value: 1.5,
            isSelected: false
          },
          {
            label: "Immobilization at least 3 days, or Surgery in the Previous 4 weeks",
            value: 1.5,
            isSelected: false
          },        
          {
            label: "Previous, objectively diagnosed PE or DVT",
            value: 1.5,
            isSelected: false
          },
          {
            label: "Hemoptysis",
            value: 1,
            isSelected: false
          },
          {
            label: "Malignancy w/ Treatment within 6 mo, or palliative",
            value: 1,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataDvt', function() {
  return {
    startState: "app.calculator_dvt",
    name: "Wells' Criteria for DVT",
    slug: "dvt",
    type: "checkbox",
    reference: "Wells PS, Anderson DR, Bormanis J, et. al “Value of assessment of pretest probability of deep-vein thrombosis in clinical management.” <em>Lancet</em> 350.9094 (1997):1795-8.",
    preText: "<p>The Wells' DVT Criteria can be used in the outpatient and emergency department setting. By risk stratifying to low risk (Wells' Score <2) and a negative d-dimer the clinician can exclude the need for ultrasound (US) to rule out DVT.</p>",
    postText: "",
    rangeThresholds: [
      {2: "low"},
      {100: "high"}
    ],
    rangeDescriptions: {
      low: "Low risk group for DVT. \"Unlikely\" according to Wells DVT studies.",
      high: "High risk group for DVT. \"Likely\" according to Wells DVT studies."
    },
    questions: [
      {
        title: "Check all that apply",
        total: 0,
        options: [
          {
            label: "Active cancer (Treatment or palliation within 6 months)",
            value: 1,
            isSelected: false
          },
          {
            label: "Bedridden recently ≥ 3 days or major surgery within 12 weeks",
            value: 1,
            isSelected: false
          },
          {
            label: "Calf swelling > 3 cm compared to the other leg",
            value: 1,
            isSelected: false
          },
          {
            label: "Collateral (nonvaricose) superficial veins present (Measured 10cm below tibial tuberosity)",
            value: 1,
            isSelected: false
          },
          {
            label: "Entire leg swollen",
            value: 1,
            isSelected: false
          },
          {
            label: "Localized tenderness along the deep venous system",
            value: 1,
            isSelected: false
          },
          {
            label: "Pitting edema, confined to symptomatic leg",
            value: 1,
            isSelected: false
          },
          {
            label: "Paralysis, paresis, or recent plaster immobilization of the lower extremity",
            value: 1,
            isSelected: false
          },
          {
            label: "Previously documented DVT",
            value: 1,
            isSelected: false
          },
          {
            label: "Alternative diagnosis to DVT at least as likely",
            value: -2,
            isSelected: false
          }          
        ]
      }
    ]
  };
})

.factory('CalcDataMgus', function() {
  return {
    startState: "app.calculator_mgus",
    name: "MGUS Progression Risk",
    slug: "mgus?questionNumber=0",
    type: "checkbox",
    reference: "Rajkumar, SV, et al “Serum free light chain ratio is an independent risk factor for progression in monoclonal gammopathy of undetermined significance.” <em>Blood</em> 106.3 (2005):812-817.",
    preText: "<p>Prediction of MGUS patients who will remain stable compared with those who progress is very difficult at the time of recognition of MGUS. However, you can select predictors associated with a higher risk of progression with this calculator to obtain a risk classification.</p>",
    postText: "",
    rangeThresholds: [
      {1: "low"},
      {2: "low-intermediate"},
      {3: "high-intermediate"},
      {4: "high"}
    ],
    rangeDescriptions: {
      "low": "Low-risk MGUS (5% absolute risk of progression at 20 years)",
      "low-intermediate": "Low intermediate-risk MGUS (21% absolute risk of progression at 20 years)",
      "high-intermediate": "High intermediate-risk MGUS (37% absolute risk of progression at 20 years)",
      "high": "High-risk MGUS (58%  absolute risk of progression at 20 years)"
    },
    questions: [
      {
        title: "Check all that apply",
        total: 0,
        options: [
          {
            label: "M-protein > 1.5 g/dL (15 g/L)",
            value: 1,
            isSelected: false
          },
          {
            label: "Non-IgG isotype",
            value: 1,
            isSelected: false
          },
          {
            label: "FLC Ratio < 0.26 or > 1.65",
            value: 1,
            isSelected: false
          }          
        ]
      }
    ]
  };
})

.factory('CalcDataFlipi', function() {
  return {
    startState: "app.calculator_flipi",
    name: "FLIPI Scoring For Follicular Lymphoma",
    short_name: "FLIPI Score",
    slug: "flipi",
    type: "checkbox",
    preText: "<p>This calculator stratifies survival rate in patients diagnosed with follicular lymphoma and certain adverse outcome factors.</p>",
    postText: "",
    reference: "Solal-Céligny, Philippe et al “Follicular Lymphoma International Prognostic Index.” <em>Blood</em> 104.5 (2004): 1258-1265.",
    rangeThresholds: [
      {2: "low"},
      {3: "intermediate"},
      {100: "high"}
    ],
    rangeDescriptions: {
      low: "Low risk group: 91% estimated survival over 5 years and 71% over 10 years.",
      intermediate: "Intermediate risk group: 78% estimated survival over 5 years and 51% over 10 years.",
      high: "High risk group: 53% estimated survival over 5 years and 36% over 10 years."
    },
    questions: [
      {
        title: "Check all that apply",
        total: 0,
        options: [
          {
            label: "Age above 60 years",
            value: 1,
            isSelected: false
          },
          {
            label: "Number of nodal areas ≥ 4",
            value: 1,
            isSelected: false
          },
          {
            label: "Elevated LDH level",
            value: 1,
            isSelected: false
          },
          {
            label: "Hemoglobin level below 12.0 g/dL",
            value: 1,
            isSelected: false
          },        
          {
            label: "Stage III/IV",
            value: 1,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataRipi', function() {
  return {
    startState: "app.calculator_ripi",
    name: "R-IPI Scoring for Diffuse Large B-Cell Lymphoma",
    short_name: "R-IPI Score",
    slug: "ripi",
    type: "checkbox",
    preText: "<p>The revised international prognostic index (R-IPI) score calculator for lymphoma prognosis stratifies survival rates based on risk factors.</p>",
    postText: "",
    reference: "Sehn, Laurie H. et al “The revised International Prognostic Index (R-IPI) is a better predictor of outcome than the standard IPI for patients with diffuse large B-cell lymphoma treated with R-CHOP.” <em>Blood</em> 109.5 (2007): 1857-1861.",
    rangeThresholds: [
      {1: "good"},
      {3: "intermediate"},
      {6: "poor"}
    ],
    rangeDescriptions: {
      good: "“Good” risk group: 94% 4-year progression free survival rate.",
      intermediate: "“Intermediate” risk group: 80% 4-year progression free survival rate.",
      poor: "“Poor” risk group: 53% 4-year progression free survival rate."
    },
    questions: [
      {
        title: "Check all that apply",
        total: 0,
        options: [
          {
            label: "Age above 60",
            value: 1,
            isSelected: false
          },
          {
            label: "Stage III or IV disease",
            value: 1,
            isSelected: false
          },
          {
            label: "Elevated serum LDH",
            value: 1,
            isSelected: false
          },
          {
            label: "ECOG performance status 3 or greater",
            value: 1,
            isSelected: false
          },        
          {
            label: "Two or more extranodal sites of disease",
            value: 1,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataBleedingScore', function() {
  return {
    startState: "app.calculator_bs",
    name: "Bleeding Score",
    slug: "bs",
    type: "radio",
    reference: "Bowman, M, Mundell, G, et al “Generation and validation of the Condensed MCMDM-1VWD Bleeding Questionnaire for von Willebrand disease.” <em>J Thromb Haemost</em> 6.12 (2008):2062-2066.",
    preText: "<p>The bleeding score is determined by scoring the worst episode for each symptom.</p> <p>Consultation only refers to a patient consulting a medical professional (doctor, nurse, dentist) because of a symptom but no treatment being given. For VWD, a bleeding score ≥ 4 has a sensitivity = 100%, specificity = 87%, positive predictive value = 0.20, negative predictive value = 1.00.</p> <p>The higher the bleeding score, the greater is the likelihood of a bleeding disorder including possible VWD.</p>",
    postText: "<p>The bleeding score is determined by scoring the worst episode for each symptom.</p> <p>Consultation only refers to a patient consulting a medical professional (doctor, nurse, dentist) because of a symptom but no treatment being given. For VWD, a bleeding score ≥ 4 has a sensitivity = 100%, specificity = 87%, positive predictive value = 0.20, negative predictive value = 1.00.</p> <p>The higher the bleeding score, the greater is the likelihood of a bleeding disorder including possible VWD.</p>",
    rangeThresholds: [
      // {4: "low"},
      // {6: "moderate"},
      // {100: "high"}
    ],
    rangeDescriptions: {},
    questions: [
      {
        title: "Epistaxis",
        total: 0,
        options: [
          {
            label: "No or trivial (< 5/year)",
            value: 0,
            isSelected: false
          },
          {
            label: "> 5/year or > 10 mins",
            value: 1,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 2,
            isSelected: false
          },
          {
            label: "Packing or cauterization or antifibrinolytic",
            value: 3,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Cutaneous",
        total: 0,
        options: [
          {
            label: "No or trivial (< 1 cm)",
            value: 0,
            isSelected: false
          },
          {
            label: ">1 cm and no trauma",
            value: 1,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 2,
            isSelected: false
          }
        ]
      },
      {
        title: "Bleeding from minor wounds",
        total: 0,
        options: [
          {
            label: "No or trivial (< 5/year)",
            value: 0,
            isSelected: false
          },
          {
            label: "> 5/year or > 5 mins",
            value: 1,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 2,
            isSelected: false
          },
          {
            label: "Surgical hemostasis",
            value: 3,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Oral cavity",
        total: 0,
        options: [
          {
            label: "No",
            value: 0,
            isSelected: false
          },
          {
            label: "Reported, no consultation",
            value: 1,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 2,
            isSelected: false
          },
          {
            label: "Surgical hemostasis or antifibrinolytic",
            value: 3,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Gastrointestinal bleeding",
        total: 0,
        options: [
          {
            label: "No",
            value: 0,
            isSelected: false
          },
          {
            label: "Assoc. with ulcer, portal hypertension, hemorrhoids, angiodysplasia",
            value: 1,
            isSelected: false
          },
          {
            label: "Spontaneous",
            value: 2,
            isSelected: false
          },
          {
            label: "Surgical hemostasis, blood transfusion, replacement therapy, desmopressin, antifibrinolytic",
            value: 3,
            isSelected: false
          }
        ]
      },
      {
        title: "Tooth extraction",
        total: 0,
        options: [
          {
            label: "No bleeding in ≥ 2 extractions",
            value: -1,
            isSelected: false
          },
          {
            label: "None done or no bleeding in 1 extraction",
            value: 0,
            isSelected: false
          },          
          {
            label: "Reported, no consultation",
            value: 1,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 2,
            isSelected: false
          },
          {
            label: "Resuturing or packing",
            value: 3,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Surgery",
        total: 0,
        options: [
          {
            label: "No bleeding in ≥ 2 surgeries",
            value: -1,
            isSelected: false
          },
          {
            label: "None done or no bleeding in 1 surgery",
            value: 0,
            isSelected: false
          },
          {
            label: "Reported, no consultation",
            value: 1,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 2,
            isSelected: false
          },
          {
            label: "Surgical hemostasis and antifibrinolytic",
            value: 3,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Menorrhagia",
        total: 0,
        options: [
          {
            label: "No",
            value: 0,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 1,
            isSelected: false
          },
          {
            label: "Antifibrinolytics, oral contraceptive pill use",
            value: 2,
            isSelected: false
          },
          {
            label: "Dilation & curettage, iron therapy, ablation",
            value: 3,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin or hysterectomy",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Postpartum hemorrhage",
        total: 0,
        options: [
          {
            label: "No bleeding in ≥ 2 deliveries",
            value: -1,
            isSelected: false
          },
          {
            label: "No deliveries or no bleeding in 1 delivery",
            value: 0,
            isSelected: false
          },
          {
            label: "Consultation only",
            value: 1,
            isSelected: false
          },
          {
            label: "Dilation & curettage, iron therapy, antifibrinolytics",
            value: 2,
            isSelected: false
          },
          {
            label: "Blood transfusion or replacement therapy or desmopressin",
            value: 3,
            isSelected: false
          },
          {
            label: "Hysterectomy",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Muscle hemotomas",
        total: 0,
        options: [
          {
            label: "Never",
            value: 0,
            isSelected: false
          },
          {
            label: "Post-trauma, no therapy",
            value: 1,
            isSelected: false
          },
          {
            label: "Spontaneous, no therapy",
            value: 2,
            isSelected: false
          },
          {
            label: "Spontaneous or traumatic, requiring desmopressin or replacement therapy",
            value: 3,
            isSelected: false
          },
          {
            label: "Spontaneous or traumatic, requiring surgical intervention or blood transfusion",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "Hemarthrosis",
        total: 0,
        options: [
          {
            label: "Never",
            value: 0,
            isSelected: false
          },
          {
            label: "Post-trauma, no therapy",
            value: 1,
            isSelected: false
          },
          {
            label: "Spontaneous, no therapy",
            value: 2,
            isSelected: false
          },
          {
            label: "Spontaneous or traumatic, requiring desmopressin or replacement therapy",
            value: 3,
            isSelected: false
          },
          {
            label: "Spontaneous or traumatic, requiring surgical intervention or blood transfusion",
            value: 4,
            isSelected: false
          }
        ]
      },
      {
        title: "CNS bleeding",
        total: 0,
        options: [
          {
            label: "Never",
            value: 0,
            isSelected: false
          },
          {
            label: "Subdural, any intervention",
            value: 3,
            isSelected: false
          },
          {
            label: "Intracerebral, any intervention",
            value: 4,
            isSelected: false
          }
        ]
      }      
    ]
  };
})

.factory('CalcData4ts', function() {
  return {
    startState: "app.calculator_4ts",
    name: "4Ts",
    slug: "4ts",
    type: "radio",
    preText: "<p>High probability (6–8 points), intermediate probability (4–5 points), low probability (≤3 points).</p><p>Adapted from Lo et al., J Thromb Haemost 2006;4:759. The 4Ts has not been compared with intuition-based diagnosis. It may be used as a guide for clinicians but should not substitute for clinical judgment. In a meta-analysis, the negative predictive value of a low probability 4T score was 99.8% (i.e. a low probability score reliably excludes HIT). The positive predictive values of intermediate and high probability scores were 14% and 64%, respectively (Cuker et al., Blood 2012;120:4160).</p>",
    postText: "<p>High probability (6–8 points), intermediate probability (4–5 points), low probability (≤3 points).</p><p>Adapted from Lo et al., J Thromb Haemost 2006;4:759. The 4Ts has not been compared with intuition-based diagnosis. It may be used as a guide for clinicians but should not substitute for clinical judgment. In a meta-analysis, the negative predictive value of a low probability 4T score was 99.8% (i.e. a low probability score reliably excludes HIT). The positive predictive values of intermediate and high probability scores were 14% and 64%, respectively (Cuker et al., Blood 2012;120:4160).</p>",
    rangeThresholds: [
      {4: "low"},
      {6: "moderate"},
      {100: "high"}
    ],
    rangeDescriptions: {},
    questions: [
      {
        title: "Thrombocytopenia",
        total: 0,
        options: [
          {
            label: "Platelet count fall > 50% and platelet nadir ≥ 20 x 109/L",
            value: 2,
            isSelected: false
          },
          {
            label: "Platelet count fall 30–50% or platelet nadir 10-19 x 109/L",
            value: 1,
            isSelected: false
          },
          {
            label: "Platelet count fall < 30% or platelet nadir < 10 x 109/L",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Timing of platelet count fall",
        total: 0,
        options: [
          {
            label: "Clear onset between days 5–14 or platelet fall ≤ 1 day (prior heparin exposure within 30 days)",
            value: 2,
            isSelected: false
          },
          {
            label: "Consistent with days 5–14 fall, but not clear (e.g. missing platelet counts) or onset after day 14 or fall ≤ 1 day (prior heparin exposure 30–100 days ago)",
            value: 1,
            isSelected: false
          },
          {
            label: "Platelet count fall ≤ 4 days without recent exposure",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Thrombosis or other sequelae",
        total: 0,
        options: [
          {
            label: "New thrombosis (confirmed); skin necrosis at heparin injection sites; anaphylactoid reaction after IV heparin bolus",
            value: 2,
            isSelected: false
          },
          {
            label: "Progressive or recurrent thrombosis; Non-necrotizing (erythematous) skin lesions; Suspected thrombosis (not confirmed)",
            value: 1,
            isSelected: false
          },
          {
            label: "None",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Other causes of thrombocytopenia",
        total: 0,
        options: [
          {
            label: "None apparent",
            value: 2,
            isSelected: false
          },
          {
            label: "Possible",
            value: 1,
            isSelected: false
          },
          {
            label: "Definite",
            value: 0,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataEcog', function() {
  return {
    startState: "app.calculator_ecog",
    name: "ECOG Performance Status",
    slug: "ecog",
    type: "radio",
    preText: "<p>This calculator assesses the functional status of patients with cancer stratified for malignancy chemotherapy.</p>",
    postText: "<p></p>",
    reference: "Oken, M.M., et al “Toxicity And Response Criteria Of The Eastern Cooperative Oncology Group.” <em>Am J Clin Oncol</em> 5 (1982): 649-655.",
    rangeThresholds: [
      // {4: "low"},
      // {6: "moderate"},
      // {100: "high"}
    ],
    rangeDescriptions: {},
    questions: [
      {
        title: "Patient Symptoms",
        total: 0,
        options: [
          {
            label: "Asymptomatic (Fully active, able to carry on all pre-disease activities without restriction)",
            value: 0,
            isSelected: false
          },
          {
            label: "Symptomatic but completely ambulatory (Restricted in physically strenuous activity but ambulatory and able to carry out work of a light or sedentary nature. For example, light housework, office work)",
            value: 1,
            isSelected: false
          },
          {
            label: "Symptomatic, <50% in bed during the day (Ambulatory and capable of all self care but unable to carry out any work activities. Up and about more than 50% of waking hours)",
            value: 2,
            isSelected: false
          },
          {
            label: "Symptomatic, >50% in bed, but not bedbound (Capable of only limited self-care, confined to bed or chair 50% or more of waking hours)",
            value: 3,
            isSelected: false
          },
          {
            label: "Bedbound (Completely disabled. Cannot carry on any self-care. Totally confined to bed or chair)",
            value: 4,
            isSelected: false
          },
          {
            label: "Death",
            value: 5,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataHCTCI', function() {
  return {
    startState: "app.calculator_hctci",
    name: "HCT Comorbidity Index",
    slug: "hctci",
    type: "radio",
    preText: "<p>The HCT-CI can assist in predicting non-relapse mortality and overall survival in patients undergoing allogeneic and autologous HCT for hematologic malignancies. By itself, the score is not intended to recommend which patients should or should not be treated with HCT.</p>",
    postText: "<p></p>",
    reference: "Sorror, Mohamed L et al “Prospective Validation of the Predictive Power of the Hematopoietic Cell Transplantation Comorbidity Index: A CIBMTR® Study.” <em>Biology of Blood and Marrow Transplantation</em> 21.8 (2015):1479–1487.",
    rangeThresholds: [
      {1: "low"},
      {3: "intermediate"},
      {100: "high"}
    ],
    rangeDescriptions: {
      low: "low",
      intermediate: "intermediate",
      high: "high"
    },
    questions: [
      {
        title: "Arrhythmia",
        info: "Arrhythmia Defined as: Atrial fibrillation or flutter, Supraventricular tachycardia, sick sinus syndrome, heart block or ventricular arrhythmias. Arrhythmia is to be scored only if required specific treatment at any time point in the patient’s past medical history.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Cardiac",
        info: "Cardiac Defined as: Coronary artery disease, congestive heart failure, myocardial infarction or ejection fraction ≤ 50%, shortening fraction < 26.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Inflammatory Bowel Disease",
        info: "Inflammatory Bowel Disease defined as: Crohn's or ulcerative colitis only if required treatment at any time point in the patient’s past medical history.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Diabetes",
        info: "Diabetes defined as: Requiring insulin or oral hypoglycemics.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Cerebrovascular Disease",
        info: "Cerebrovascular Disease Defined as: TIA, Subarachnoid hemorrhage, Cerebral thrombosis, Cerebral embolism, or Cerebral hemorrhage.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Psychiatric Disturbance",
        info: "Psychiatric Disturbance Defined as: Depression, anxiety or other requiring continuous psychiatric treatment.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Hepatic Disease",
        info: "",
        total: 0,
        options: [
          {
            label: "Moderate or Severe (cirrhosis, bilirubin > 1.5 x ULN, or AST/ALT > 2.5 x ULN)",
            value: 3,
            isSelected: false
          },
          {
            label: "Mild (hepatitis B or C, bilirubin > ULN to 1.5 x ULN, or AST/ALT > ULN to 2.5 x ULN)",
            value: 1,
            isSelected: false
          },
          {
            label: "None",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Obesity",
        info: "Defined as: Body mass index > 35kg/m².",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Infection",
        info: "Defined as: Requiring continuation of antimicrobial treatment or TB prophylaxis for PPD positive patients after day 0.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Rheumatologic",
        info: "Defined as: SLE, RA, polymyositis, mixed CTD, or polymyalgia rheumatic  if required specific treatment at any time point.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 2,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Peptic Ulcer",
        info: "Defined as:  a prior endoscopic diagnosis of gastric or duodenal ulcer any time point in the patient’s past medical history.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 2,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Moderate or Severe Renal Failure",
        info: "Defined as: Serum creatinine >2 mg/dL (or >177 µmol/L), on dialysis (within 4 weeks prior to start of conditioning regimen), or prior renal transplantation.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 2,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Pulmonary Disease",
        info: "",
        total: 0,
        options: [
          {
            label: "Severe (DLCO and/or FEV1 ≤ 65% or dyspnea at rest or requiring oxygen)",
            value: 3,
            isSelected: false
          },
          {
            label: "Moderate (DLCO and/or FEV1 66%-80% or dyspnea on slight activity)",
            value: 2,
            isSelected: false
          },
          {
            label: "None",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Prior Solid Tumor",
        info: "Note: Any solid tumor that required specific treatment at any time point in the patient’s past medical history regardless of the type of treatment (surgery, radiotherapy, and/or drug therapy). Lymphomas are to be scored for this comorbidity only if the primary malignant diagnosis is of a myeloid nature (for example acute myeloid leukemia or myelodysplastic syndromes, or chronic myeloid leukemia). Melanoma is the only type of skin cancer to be scored for this comorbidity.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 3,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Heart Valve Disease",
        info: "Note: Except symptomatic mitral valve prolapse.",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 3,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Age 40 or older",
        info: "",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataKhorana', function() {
  return {
    startState: "app.calculator_khorana",
    name: "VTE Clinical Risk Score (Khorana) in Ambulatory Cancer Patients",
    short_name: "VTE Clinical Risk Score",
    slug: "khorana",
    type: "radio",
    preText: "<p>Predicts risk of venous thromboembolism (VTE) for cancer patients depending on type of cancer and other factors.</p>",
    postText: "<p></p>",
    reference: "Khorana, Alok A. et al “Development and validation of a predictive model for chemotherapy-associated thrombosis.” <em>Blood</em> 111.10 (2008): 4902-4907",
    rangeThresholds: [
      {1: "low"},
      {3: "intermediate"},
      {100: "high"}
    ],
    rangeDescriptions: {
      low: "Low Risk. Rate of VTE at 2.5 months = 0.3 - 0.8% (Median follow-up time was 2.5 months)",
      intermediate: "Intermediate Risk. Rate of VTE at 2.5 months* = 1.8 - 2.0% (Median follow-up time was 2.5 months)",
      high: "High Risk. Rate of VTE at 2.5 months* = 6.7 - 7.1% (Median follow-up time was 2.5 months)"
    },
    questions: [
      {
        title: "Cancer type",
        total: 0,
        options: [
          {
            label: "Stomach",
            value: 2,
            isSelected: false
          },
          {
            label: "Pancreas",
            value: 2,
            isSelected: false
          },
          {
            label: "Lung",
            value: 1,
            isSelected: false
          },
          {
            label: "Lymphoma",
            value: 1,
            isSelected: false
          },
          {
            label: "Gynecologic",
            value: 1,
            isSelected: false
          },
          {
            label: "Bladder",
            value: 1,
            isSelected: false
          },
          {
            label: "Testicular",
            value: 1,
            isSelected: false
          },
          {
            label: "Other",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Pre-chemotherapy platelet count ≥350x10⁹/L",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Hemoglobin level <10 g/dL or using RBC growth factors",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "Pre-chemotherapy leukocyte count ≥11x10⁹/L",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      },
      {
        title: "BMI ≥35 kg/m²",
        total: 0,
        options: [
          {
            label: "Yes",
            value: 1,
            isSelected: false
          },
          {
            label: "No",
            value: 0,
            isSelected: false
          }
        ]
      }
    ]
  };
})

.factory('CalcDataIpss', function() {
  return {
    startState: "app.calculator_ipss",
    name: "Myelodysplastic Syndrome IPSS",
    slug: "ipss",
    type: "radio",
    preText: "<p>Myelodysplastic syndromes are a heterogeneous group of diseases with variable outcomes. Patients with low-risk disease often have longer survivals and the primary therapeutic goals include improvement of ineffective hematopoiesis and reduction of iron overload. Higher risk patients are managed with the goal of delaying transformation to acute leukemia and extending survival. The International Prognostic Scoring System is the most commonly used tool in MDS to predict long-term outcome.</p>",
    postText: "<p></p>",
    reference: "",
    rangeThresholds: [
      {0.1: "low"},
      {1.1: "intermediate_level_one"},
      {2.1: "intermediate_level_two"},
      {100: "high"}
    ],
    rangeDescriptions: {
      low: "Low Risk. Median survival: 5.7 years",
      intermediate_level_one: "Intermediate Risk (level 1). Median survival: 3.5 years",
      intermediate_level_two: "Intermediate Risk (level 2). Median survival: 1.2 years",
      high: "High Risk. Median survival: 0.4 years"
    },
    questions: [
      {
        title: "BM Blasts",
        total: 0,
        options: [
          {
            label: "< 5%",
            value: 0
          },
          {
            label: "5-10%",
            value: 0.5
          },
          {
            label: "11-20%",
            value: 1.5
          },
          {
            label: "21-29%",
            value: 2
          }
        ]
      },
      {
        title: "Karyotype",
        total: 0,
        options: [
          {
            label: "Good (Normal, -Y, del(5q), or del(20q))",
            value: 0
          },
          {
            label: "Intermediate (Other Abnormalities)",
            value: 0.5
          },
          {
            label: "Poor (Complex: 3 or More Abnormalities, or Chromosome 7 Anomalies)",
            value: 1
          }
        ]
      },
      {
        title: "Number of Cytopenias",
        info: "Cytopenias defined as: Hb <100 g/L, ANC <1800/uL, and platelets <100,000/mm³",
        total: 0,
        options: [
          {
            label: "0-1",
            value: 0
          },
          {
            label: "2-3",
            value: 0
          }
        ]
      }
    ]
  };
});


