var TEXTPAND_TIMEOUT = 300;

angular.module('hemo.controllers', ['hemo.services', 'hemo.directives'])

.controller('CalculatorController', function($scope, $state, $stateParams, $rootScope, CalcFavoriteable, Calculator, calcDataObj) {
  var calc = Calculator.init(calcDataObj);

  if (typeof($stateParams.questionNumber) != "undefined") {
    calc.goToQuestion(parseInt($stateParams.questionNumber));
  } else {
    calc.reset();
  }

  $scope.goNext = function() {
    $state.go(calc.data.startState, {questionNumber: calc.questionNumber + 1});
  };

  $scope.reset = function() {
    $state.go(calc.data.startState, {questionNumber: null});
  };

  $scope.done = function() {
    calc.reset();
    $state.go("app.tools");
  };

  // need to proxy to the calc object, otherwise animations
  // get jacked (?!) if calc is put directly in $scope ¯\_(ツ)_/¯
  $scope.calc = {
    data: calc.data,
    type: calc.data.type,
    questionNumber: calc.questionNumber,
    isIntroPage: calc.isIntroPage(),
    isFinished: calc.isFinished(),
    getTotal: calc.getTotal(),
    hasAnswer: calc.hasAnswer(),
    answerQuestion: function() {
      calc.answerQuestion();
    },
    chooseOption: function(index) {
      calc.chooseOption(index);
      this.hasAnswer = true;
    },
    getRange: calc.getRange(),
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited(calc.data.slug);
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, calc.data.slug);
  };

})

.controller('CheckboxCalculatorController', function($scope, $state, $stateParams, OnePageCheckboxCalculator, calcDataObj, CalcFavoriteable) {
  var calc = OnePageCheckboxCalculator.init(calcDataObj);

  if (typeof($stateParams.questionNumber) != "undefined") {
    calc.goToQuestion(parseInt($stateParams.questionNumber));
  } else {
    calc.reset();
  }

  $scope.reset = function() {
    $state.go(calc.data.startState, {questionNumber: null});
  };

  $scope.goNext = function() {
    $state.go(calc.data.startState, {questionNumber: calc.questionNumber + 1});
  };

  $scope.done = function() {
    calc.reset();
    $state.go("app.tools");
  };

  // need to proxy to the calc object, otherwise animations
  // get jacked (?!) if calc is put directly in $scope ¯\_(ツ)_/¯
  $scope.calc = {
    data: calc.data,
    type: calc.data.type,
    questionNumber: calc.questionNumber,
    isIntroPage: calc.isIntroPage(),
    getTotal: 0,
    updateTotal: function() {
      this.getTotal = calc.getTotal();
    },
    chooseOption: function(index) {
      calc.chooseOption(index);
      this.hasAnswer = true;
    },
    rangeDescription: calc.getRange().rangeDescription,
    updateRange: function() {
      this.rangeDescription = calc.getRange().rangeDescription;
    },
    name: calc.getName()
  };

  $scope.calc.updateTotal();

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited(calc.data.slug);
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, calc.data.slug);
  };

})

.controller('HCTCICalcController', function($scope, $state, $stateParams, $rootScope, HCTCICalc, calcDataObj, CalcFavoriteable) {
  var calc = HCTCICalc.init(calcDataObj);

  if (typeof($stateParams.questionNumber) != "undefined") {
    calc.goToQuestion(parseInt($stateParams.questionNumber));
  } else {
    calc.reset();
  }

  $scope.goNext = function() {
    $state.go(calc.data.startState, {questionNumber: calc.questionNumber + 1});
  };

  $scope.reset = function() {
    $state.go(calc.data.startState, {questionNumber: null});
  };

  $scope.done = function() {
    calc.reset();
    $state.go("app.tools");
  };

  $scope.calc = {
    data: calc.data,
    type: calc.data.type,
    questionNumber: calc.questionNumber,
    isIntroPage: calc.isIntroPage(),
    isFinished: calc.isFinished(),
    getTotal: calc.getTotal(),
    getPreAgeTotal: calc.getPreAgeTotal(),
    hasAnswer: calc.hasAnswer(),
    answerQuestion: function() {
      calc.answerQuestion();
    },
    chooseOption: function(index) {
      calc.chooseOption(index);
      this.hasAnswer = true;
    },
    getRange: calc.getRange(),
    getPreAgeRange: calc.getPreAgeRange()
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited(calc.data.slug);
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, calc.data.slug);
  };

})

.controller('MgusRecController', function($scope, $stateParams) {
  var levels = {
    "0": "low",
    "1": "low intermediate",
    "2": "high intermediate",
    "3": "high"
  };

  $scope.data = {
    score: $stateParams.result,
    level: levels[$stateParams.result]
  };
})

.controller('NaglerController', function($scope, $stateParams) {
  // console.log($stateParams.fourTs);
})

.controller('IpssrController', function($scope, $stateParams, $state, $ionicPopup, IpssrData, IpssrCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  if (!IpssrData.cyto) {
    IpssrData.cyto = "0";
  }

  $scope.data = {
    calc: IpssrData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = IpssrCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        IpssrCalc.calculate();
      }
    }

    $state.go('app.ipssr', { page: nextPage });
  };

  $scope.reset = function() {
    IpssrCalc.reset();
    $state.go('app.ipssr', { page: 0 });
  };

  $scope.done = function() {
    IpssrCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('ipssr?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'ipssr?page=0');
  };

})

.controller('CreatinineClearanceController', function($scope, $stateParams, $state, $ionicPopup, CreatinineClearanceData, CreatinineClearanceCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  if (!CreatinineClearanceData.sex) {
    CreatinineClearanceData.sex = "M";
  }

  if (!CreatinineClearanceData.weightUnit) {
    CreatinineClearanceData.weightUnit = "kg";
  }

  $scope.data = {
    calc: CreatinineClearanceData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = CreatinineClearanceCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        CreatinineClearanceCalc.calculate();
      }
    }

    $state.go('app.creatinine', { page: nextPage });
  };

  $scope.reset = function() {
    CreatinineClearanceCalc.reset();
    $state.go('app.creatinine', { page: 0 });
  };

  $scope.done = function() {
    CreatinineClearanceCalc.reset();
    $state.go('app.tools');
  }

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('creatinine?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'creatinine?page=0');
  };

})

.controller('MipiController', function($scope, $stateParams, $state, $ionicPopup, MipiData, MipiCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  if (!MipiData.ecog) {
    MipiData.ecog = "0-1";
  }

  $scope.data = {
    calc: MipiData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = MipiCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        MipiCalc.calculate();
      }
    }

    $state.go('app.mipi', { page: nextPage });
  };

  $scope.reset = function() {
    MipiCalc.reset();
    $state.go('app.mipi', { page: 0 });
  };

  $scope.done = function() {
    MipiCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('mipi?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'mipi?page=0');
  };
})

.controller('IronController', function($scope, $stateParams, $state, $ionicPopup, IronData, IronCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  if (!IronData.ageFactor) {
    IronData.ageFactor = 14.8;
  }

  if (!IronData.weightUnit) {
    IronData.weightUnit = "kg";
  }

  $scope.data = {
    calc: IronData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = IronCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        IronCalc.calculate();
      }
    }

    $state.go('app.iron', { page: nextPage });
  };

  $scope.reset = function() {
    IronCalc.reset();
    $state.go('app.iron', { page: 0 });
  };

  $scope.done = function() {
    IronCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('iron?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'iron?page=0');
  };

})

.controller('EutosController', function($scope, $stateParams, $state, $ionicPopup, EutosData, EutosCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  $scope.data = {
    calc: EutosData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = EutosCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        EutosCalc.calculate();
      }
    }

    $state.go('app.eutos', { page: nextPage });
  };

  $scope.reset = function() {
    EutosCalc.reset();
    $state.go('app.eutos', { page: 0 });
  };

  $scope.done = function() {
    EutosCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('eutos?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'eutos?page=0');
  };

})

.controller('FactorViiiController', function($scope, $stateParams, $state, $ionicPopup, FactorViiiData, FactorViiiCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  if (!FactorViiiData.weightUnit) {
    FactorViiiData.weightUnit = "kg";
  }

  $scope.data = {
    calc: FactorViiiData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = FactorViiiCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        FactorViiiCalc.calculate();
      }
    }

    $state.go('app.factorviii', { page: nextPage });
  };

  $scope.reset = function() {
    FactorViiiCalc.reset();
    $state.go('app.factorviii', { page: 0 });
  };

  $scope.done = function() {
    FactorViiiCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('factorviii?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'factorviii?page=0');
  };

})

.controller('FactorIxController', function($scope, $stateParams, $state, $ionicPopup, FactorIxData, FactorIxCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  if (!FactorIxData.weightUnit) {
    FactorIxData.weightUnit = "kg";
  }

  $scope.data = {
    calc: FactorIxData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = FactorIxCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        FactorIxCalc.calculate();
      }
    }

    $state.go('app.factorix', { page: nextPage });
  };

  $scope.reset = function() {
    FactorIxCalc.reset();
    $state.go('app.factorix', { page: 0 });
  };

  $scope.done = function() {
    FactorIxCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('factorix?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'factorix?page=0');
  };
})

.controller('RedCellExchangeController', function($scope, $stateParams, $state, $ionicPopup, RedCellExchangeData, RedCellExchangeCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  $scope.data = {
    calc: RedCellExchangeData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = RedCellExchangeCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        RedCellExchangeCalc.calculate();
      }
    }

    $state.go('app.red_cell_exchange', { page: nextPage });
  };

  $scope.reset = function() {
    RedCellExchangeCalc.reset();
    $state.go('app.red_cell_exchange', { page: 0 });
  };

  $scope.done = function() {
    RedCellExchangeCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('red_cell_exchange?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'red_cell_exchange?page=0');
  };
})

.controller('SokalController', function($scope, $stateParams, $state, $ionicPopup, SokalData, SokalCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  $scope.data = {
    calc: SokalData
  };

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      break;
    case "1":
      $scope.data.page = "question";
      break;
    case "2":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 2) {
      var error = SokalCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        SokalCalc.calculate();
      }
    }

    $state.go('app.sokal', { page: nextPage });
  };

  $scope.reset = function() {
    SokalCalc.reset();
    $state.go('app.sokal', { page: 0 });
  };

  $scope.done = function() {
    SokalCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('sokal?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'sokal?page=0');
  };
})

.controller('MyelomaFrailtyController', function($scope, $stateParams, $state, $ionicPopup, MyelomaFrailtyData, MyelomaFrailtyCalc, CalcFavoriteable) {

  $scope.$on( '$ionicView.afterEnter', function () {
    // Handle iOS-specific issue with jumpy viewport when interacting with input fields.
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      cordova.plugins.Keyboard.disableScroll( true );
    }
  });

  $scope.$on( '$ionicView.beforeLeave', function () {
    if ( window.cordova && window.cordova.plugins.Keyboard ) {
      // return to keyboard default scroll state
      cordova.plugins.Keyboard.disableScroll( false );
    }
  });

  // if (!IpssrData.cyto) {
  //   IpssrData.cyto = "0";
  // }

  $scope.data = {
    calcdata: MyelomaFrailtyData,
    calc: MyelomaFrailtyCalc
  };

  // console.log(JSON.stringify($scope.data.calc.questions.charlson));
  // console.log(JSON.stringify($scope.data.calc.data.questions.charlson));

  switch ($stateParams.page) {
    case "0":
      $scope.data.page = "intro";
      $scope.data.calc.reset();
      break;
    case "1":
      $scope.data.page = "charlson";
      break;
    case "2":
      $scope.data.page = "badl";
      break;
    case "3":
      $scope.data.page = "iadl";
      break;
    case "4":
      $scope.data.page = "age";
      break;
    case "5":
      $scope.data.page = "score";
      break;
  }

  $scope.goNext = function() {
    var nextPage = parseInt($stateParams.page) + 1;

    if (nextPage == 5) {
      var error = MyelomaFrailtyCalc.validate();
      if (error) {

        var alertPopup = $ionicPopup.alert({
          title: 'Error',
          template: error
        });

        alertPopup;

        return;
      } else {
        MyelomaFrailtyCalc.calculate();
      }
    }

    $state.go('app.myeloma-frailty', { page: nextPage });
  };

  $scope.reset = function() {
    $state.go('app.myeloma-frailty', { page: 0 });
  };

  $scope.done = function() {
    MyelomaFrailtyCalc.reset();
    $state.go('app.tools');
  };

  CalcFavoriteable.init();
  $scope.favorited = CalcFavoriteable.isFavorited('myelomafrailty?page=0');
  $scope.toggleFavorite = function() {
    CalcFavoriteable.toggle($scope, 'myelomafrailty?page=0');
  };
})

.controller('GuideController',
  function($scope, $state, $stateParams, DataLoader, $ionicPopup, $ionicScrollDelegate, $localstorage) {
    $scope.toggleTextpand = function(child) {
      child.hide = !child.hide;
      setTimeout(resizeScreen, TEXTPAND_TIMEOUT + 5);

      function resizeScreen() {
        $ionicScrollDelegate.resize();
      }
    };

    $scope.ratingPopup = function(recommendation, evidence) {
      var recommendationQuality, evidenceQuality, details;
      var recommendationOptions = {
        '1': 'Strong',
        '2': 'Moderate',
        '3': 'Weak'
      };
      var evidenceOptions = {
        '1': 'high',
        '2': 'moderate',
        '3': 'low',
        '4': 'very low'
      };

      recommendationQuality = recommendationOptions[recommendation];
      evidenceQuality = evidenceOptions[evidence];

      $ionicPopup.alert({
        title: recommendationQuality + ' recommendation, ' + evidenceQuality + ' quality evidence'
      });
    };

    $scope.ratingPopupAlt = function(recommendation, evidence) {
      var recommendationQuality, evidenceQuality;
      var recommendationOptions = {
        '1': 'Strong recommendation',
        '2': 'Recommendation',
        '3': 'Expert consensus opinion'
      };
      var evidenceOptions = {
        '1': 'convincing',
        '2': 'adequate',
        '3': 'inadequate',
        '4': 'insufficient'
      };

      recommendationQuality = recommendationOptions[recommendation];
      evidenceQuality = evidenceOptions[evidence];

      $ionicPopup.alert({
        title: recommendationQuality + ', ' + evidenceQuality + ' evidence'
      });
    };

    $scope.consensusPopup = function(quality) {
      $ionicPopup.alert({
        title: 'Expert Panel Consensus'
      });
    };

    $scope.recommendationPopup = function(key) {
      var recommendationOptions = {
        '1': 'Strong recommendation',
        '2': 'Conditional recommendation'
      };

      $ionicPopup.alert({
        title: recommendationOptions[key]
      });
    };


    // favorites indexed by guide id: {"1": false, "6": true}

    var initFavorites = function() {
      var favorites = $localstorage.getObject('favorites');
      $scope.favorited = favorites[$stateParams.guideId];
      // console.log("favs:", JSON.stringify(favorites));
    };

    $scope.toggleFavorite = function() {
      var favorites = $localstorage.getObject('favorites');
      $scope.favorited = !$scope.favorited;
      favorites[$stateParams.guideId] = $scope.favorited;
      // console.log("favorites[$stateParams.guideId]",favorites[$stateParams.guideId]);
      $localstorage.setObject('favorites', favorites);
    };

    DataLoader(function(response) {
      var data, currentGuide;
      var tabIndex = 0;
      // find the desired object, regarless of whether it's from a live HTTP response or from
      // local storage.
      if (response.data) {
        data = response.data;
      } else {
        data = response;
      }
      if ($stateParams.pageId) {
        // console.log("pageId", $stateParams.pageId);
        var currentPage = data.pages[$stateParams.pageId];
        $scope.currentPage = currentPage;
        currentGuide = data.guides[currentPage.guide_id];
        $scope.body = currentPage.content;
        $scope.children = currentPage.children;
        $scope.pageType = currentPage.page_type;
        $scope.pageLabel = currentPage.label;
        if (currentPage.page_type === 'tabs') {
          $scope.selectedTab = 0;
        }
        $scope.pageTitle = currentPage.title;
      } else {
        // console.log("guideId", $stateParams.guideId);
        $scope.favoriteable = true;
        initFavorites();
        currentGuide = data.guides[$stateParams.guideId];
        if (currentGuide) {
          $scope.header = currentGuide.header;
          $scope.children = currentGuide.children;
          $scope.pageTitle = currentGuide.name;
        } else {
          $state.go('app.home');
        }
      }
      
      ga('send', {
        hitType: 'screenview',
        screenName: $scope.pageTitle,
        appName: 'ASH Pocket Guides'
      });
      
      // TODO why is this commented out? do we not use background imagefilnemae any more?
      // if (currentGuide.background_image_filename) {
      //   $scope.headerStyle = "background-image: url('../img/" +
      //     currentGuide.background_image_filename + "')";
      // }
      setChildren($scope.children, data, tabIndex);
      $scope.selectTab = function(idx) {
        $scope.selectedTab = idx;
      };
      return data;
    });

  }
)

.controller('HomeController', function($scope, $ionicScrollDelegate, DataLoader, WHICH_CMS, $localstorage, $ionicFilterBar, $ionicPopup) {
    // TODO consolidate w/ guide?
    $scope.toggleTextpand = function(child) {
      child.hide = !child.hide;
      setTimeout(resizeScreen, TEXTPAND_TIMEOUT + 5);

      function resizeScreen() {
        $ionicScrollDelegate.resize();
      }
    };

    if ('production' != WHICH_CMS) {
      $scope.shouldShowCmsBanner = true;
      $scope.cms = WHICH_CMS;
    }

    // TODO examine same in Guide controller, refactorable?
    DataLoader(function(response) {
      var data;
      //var tabIndex = 0;
      if (response.data) {
        data = response.data;
      } else {
        data = response;
      }

      $scope.guides = data.homepage_items;
      $scope.originalGuides = data.homepage_items;

      var favorites = $localstorage.getObject('favorites');
      $scope.favoriteGuides = [];

      var selectFavorites = function(guideArray, accum) {
        angular.forEach(guideArray, function(guide, i) {
          if (guide.guide_type == "grouping") {
            selectFavorites(guide.children, accum);
          } else {
            if (favorites[guide.id.toString()]) {
              this.push(guide);
            }
          }
        }, accum);
      };

      selectFavorites(data.homepage_items, $scope.favoriteGuides);

      $scope.guidesForSearch = []; // guides array, with grouped guides flattened      

      var selectGuidesForSearch = function(guideArray, accum) {
        angular.forEach(guideArray, function(guide, i) {
          if (guide.guide_type == "grouping") {
            selectGuidesForSearch(guide.children, accum);
          } else {
            // filter out dupes
            if (this.filter(function(e) { return e.name == guide.name; }).length == 0) {
              guide.guide_type = (guide.linked_id != null) ? "link" : "standard";
              this.push(guide);
            }
          }
        }, accum);
      };

      selectGuidesForSearch(data.homepage_items, $scope.guidesForSearch);

      ga('send', {
        hitType: 'screenview',
        screenName: 'Guide List',
        appName: 'ASH Pocket Guides'
      });
      
      return data;
    });

    $scope.showingSearchResults = false;

    $scope.showFilterBar = function(data) {
      $ionicFilterBar.show({
        items: $scope.guidesForSearch,
        update: function (filteredItems) {
          $scope.guides = filteredItems;
          $scope.showingSearchResults = true;
        },
        cancel: function() {
          $scope.showingSearchResults = false;
          $scope.guides = $scope.originalGuides;
        },
        // match on 'name' OR 'keywords' fields
        expression: function (filterText, value, index, array) {
          var re = new RegExp(filterText,"i");
          return re.test(value.name) || re.test(value.keywords);
        }
        // filterProperties: ['name']
      });
    };

    var showPopup = function() {

      var disclaimerPopup = $ionicPopup.show({
        title: "ASH Pocket Guides App Terms of Use",
        templateUrl: "templates/terms-text.html",
        cssClass: "disclaimer-popup",
        scope: $scope,
        buttons: [
          {
            text: '<b>Ok</b>',
            type: 'button-positive'
          }
        ]
      });

      disclaimerPopup.then(function(res) {
        $localstorage.set('disclaimer', 'y');
      });

    };

    var seenDisclaimer = $localstorage.get('disclaimer', null);
    if (!seenDisclaimer) {
      showPopup();
    }

  }
)

.controller('ToolsController', function($scope, $ionicFilterBar, $localstorage, $filter) {
  $scope.items = [
    {
      name: "4Ts Clinical Probability Scoring for HIT",
      slug: "4ts",
      type: "calc"
    },
    {
      name: "Bleeding Score",
      slug: "bs",
      type: "calc"
    },
    {
      name: "Creatinine Clearance (Cockcroft-Gault)",
      slug: "creatinine?page=0",
      type: "calc"
    },
    {
      name: "ECOG Performance Status",
      slug: "ecog",
      type: "calc"
    },
    {
      name: "EUTOS Score For CML",
      slug: "eutos?page=0",
      type: "calc"
    },
    {
      name: "FLIPI Scoring For Follicular Lymphoma",
      slug: "flipi",
      type: "calc"
    },
    {
      name: "Factor VIII Dosage for Hemophilia",
      slug: "factorviii?page=0",
      type: "calc"
    },
    {
      name: "Factor IX Dosage for Hemophilia",
      slug: "factorix?page=0",
      type: "calc"
    },
    {
      name: "HCT Comorbidity Index",
      slug: "hctci",
      type: "calc"
    },
    {
      name: "IPSS-R for Prognosis in MDS",
      slug: "ipssr?page=0",
      type: "calc"
    },
    // {
    //   name: "Iron Replacement Dosing",
    //   slug: "iron?page=0",
    //   type: "calc"
    // },
    {
      name: "MGUS Progression Risk",
      slug: "mgus?questionNumber=0",
      type: "calc"
    },
    {
      name: "MIPI Scoring for Mantle Cell Lymphoma",
      slug: "mipi?page=0",
      type: "calc"
    },
    // {
    //   name: "Myeloma Frailty Score",
    //   slug: "myelomafrailty?page=0",
    //   type: "calc"
    // },
    // {
    //   name: "Myelodysplastic Syndrome IPSS",
    //   slug: "ipss",
    //   type: "calc"
    // },
    {
      name: "R-IPI Scoring for Diffuse Large B-Cell Lymphoma",
      slug: "ripi",
      type: "calc"
    },
    // {
    //   name: "Red Blood Cell Exchange",
    //   slug: "red_cell_exchange?page=0",
    //   type: "calc"
    // },
    {
      name: "Sokal Score For CML",
      slug: "sokal?page=0",
      type: "calc"
    },
    {
      name: "VTE Clinical Risk Score (Khorana) in Ambulatory Cancer Patients",
      slug: "khorana",
      type: "calc"
    },
    {
      name: "Wells' Criteria for DVT",
      slug: "dvt",
      type: "calc"
    },
    {
      name: "Wells' Criteria for Pulmonary Embolism",
      slug: "pe",
      type: "calc"
    },
    {
      name: "Initial Warfarin Dosing",
      slug: "guides/1/pages/105",
      type: "dt"
    },
    {
      name: "Chronic Warfarin Dose Adjustment",
      slug: "decisiontree/3",
      type: "dt"
    },
    {
      name: "VWD Assessment Algorithm",
      slug: "decisiontree/4",
      type: "dt"
    },
    {
      name: "Diagnostic and Initial Treatment Algorithm for HIT",
      slug: "decisiontree/1",
      type: "dt"
    },
    {
      name: "Initial Diagnostic Workup of Acute Leukemia",
      slug: "acute-leukemia",
      type: "dt"
    },
    {
      name: "Prophylaxis for Women Not Receiving Long-Term Anticoagulation Therapy",
      slug: "decisiontree/6",
      type: "dt"
    },
    {
      name: "When to Offer Prophylaxis in the Context of Thrombophilia",
      slug: "decisiontree/7",
      type: "dt"
    },
    {
      name: "Anticoagulation and Delivery Assessment",
      slug: "decisiontree/8",
      type: "dt"
    },
    {
      name: "Inpatient vs. Outpatient Management",
      slug: "decisiontree/9",
      type: "dt"
    },
    {
      name: "Second Line Therapies for Adults",
      slug: "decisiontree/10",
      type: "dt"
    }
  ];

  var favorites = $localstorage.getObject('favorites');
  $scope.favoriteTools = [];
  if (!favorites.tools) {
    favorites.tools = [];
  }
  angular.forEach(favorites.tools, function(slug, i) {
    var item = $filter('filter')($scope.items, {'slug':slug})[0];
    this.push(item);
  }, $scope.favoriteTools);

  $scope.showingSearchResults = false;

  $scope.showFilterBar = function(data) {
    $ionicFilterBar.show({
      items: $scope.items,
      update: function (filteredItems) {
        $scope.items = filteredItems;
        $scope.showingSearchResults = true;
      },
      cancel: function() {
        $scope.showingSearchResults = false;
      },
      filterProperties: ['name']
    });
  };

})

.controller('DecisionTree',
  function($scope, $state, $stateParams, $ionicHistory, $ionicPopup) {
    $scope.goBack = function(backNum) {
      $ionicHistory.goBack(backNum);
    };

    var currentQuestionNumber;
    var numBack = 0;
    var tree = DECISION_TREES[$stateParams.decisionTreeId];
    if ($stateParams.numBack) {
      numBack = parseInt($stateParams.numBack) + 1;
    }
    $scope.decisionTreeId = $stateParams.decisionTreeId;
    if ($stateParams.questionNumber) {
      currentQuestionNumber = $stateParams.questionNumber;
    } else {
      currentQuestionNumber = tree.firstId;
    }

    $scope.model = {
      'nextQ': 0,
      'numBack': numBack,
      'questions': tree[currentQuestionNumber].questions,
      'text': tree[currentQuestionNumber].text,
      'treeTitle': tree.title,
      'footnote': tree[currentQuestionNumber].footnote
    };

    $scope.recommendationPopup = function(key) {
      var recommendationOptions = {
        '1': 'Strong recommendation',
        '2': 'Conditional recommendation'
      };

      $ionicPopup.alert({
        title: recommendationOptions[key]
      });
    };

  }
)

.controller('AcuteLeukemiaController', function($scope, $stateParams, $state, $ionicScrollDelegate, $ionicPopup) {
  $scope.page = $stateParams.page;

  $scope.selectedButton = 'b';

  $scope.selectButton = function(button) {
    $scope.selectedButton = button;
  };

  $scope.go = function(page) {
    $state.go("app.acute_leukemia", { page: page })
  };

  $scope.expandables = {
    cbf:   true,
    apl:   true,
    other: true
  };

  $scope.toggleTextpand = function(child) {
    // child.hide = !child.hide;
    $scope.expandables[child] = !($scope.expandables[child])
    setTimeout(resizeScreen, TEXTPAND_TIMEOUT + 5);

    function resizeScreen() {
      $ionicScrollDelegate.resize();
    }
  };

  $scope.ratingPopupAlt = function(recommendation, evidence) {
    var recommendationQuality, evidenceQuality;
    var recommendationOptions = {
      '1': 'Strong recommendation',
      '2': 'Recommendation',
      '3': 'Expert consensus opinion'
    };
    var evidenceOptions = {
      '1': 'convincing',
      '2': 'adequate',
      '3': 'inadequate',
      '4': 'insufficient'
    };

    recommendationQuality = recommendationOptions[recommendation];
    evidenceQuality = evidenceOptions[evidence];

    $ionicPopup.alert({
      title: recommendationQuality + ', ' + evidenceQuality + ' evidence'
    });
  };

})

.controller('AcuteLeukemiaKeyController', function($scope) {
})

.controller('HitKeyController', function($scope) {
})

.controller('MatKeyController', function($scope) {
})

.controller('VteKeyController', function($scope) {
})

.controller('ScdtsKeyController', function($scope) {
})

.controller('ItpKeyController', function($scope) {
})

.controller('CardiopulmonarySCDKeyController', function($scope) {
})

// Textpander animation handling

.animation('.visible', function() {
	return {
		addClass: function(element, className, done) {
      jQuery(element).slideUp(TEXTPAND_TIMEOUT, done);
		},
		removeClass: function(element, className, done) {
			jQuery(element).slideDown(TEXTPAND_TIMEOUT, done);
		}
	}
})

//
// For GuideController
//
function setChildren(children, data, tabIndex) {
  for (var child in children) {
    var currentChild = children[child];
    var newChild = data.pages[currentChild.id];
    newChild.id = currentChild.id;
    newChild.tabIndex = tabIndex;
    if ('textpanding' === newChild.page_type) {
      // this sets tabIndex to weird values, but since it only runs for textpanders, that should
      // in theory be OK
      setChildren(newChild.children, data, tabIndex);
    }
    tabIndex++;
    children[child] = newChild;
  }
}

// TODO evaluate if there's a better place to stash this
var DECISION_TREES = {
  "12": {
    "title": "Pulmonary Arterial Hypertension (PAH) Therapies",
    "firstId": 1,
    "1": {
      "text": "<h2>Patients with SCD who have undergone right heart catheterization",
      "questions": [
        { "label": "Confirmed diagnosis of PAH",
          "id": 2
        },
        {
          "label": "No confirmed diagnosis of PAH",
          "id": 3
        }
      ],
    },
    "2": {
      "text": "<p>Use of PAH-specific therapies under the care of a pulmonary hypertension specialist <strong>suggested</strong><sup>1</sup> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><p><sup>1</sup><em>Given the lack of alternative treatment options and high morbidity and mortality associated with PAH.</em></p>",
    },
    "3": {
      "text": "<p> No use of PAH-specific therapies <strong>recommended</strong> <a ng-click='recommendationPopup(1)'><span class='rating-1'></span></a></p>",
    }
  },
  "11": {
    "title": "Right-Heart Catheterization vs. Non-Invasive Monitoring",
    "firstId": 1,
    "1": {
      "text": "<h2>Patients with SCD suspected to have pulmonary hypertension based on an abnormal ECHO<sup>1</sup></h2>",
      "questions": [
        { "label": "Asymptomatic patients with isolated TRJV ≥ 2.5 to 2.9 m/sec<sup>2</sup>",
          "id": 2
        },
        {
          "label": "Patients with TRJV ≥ 2.5 m/sec who also have reduced 6MWD",
          "id": 3
        },
        {
          "label": "Patients with TRJV ≥ 2.5 m/sec who also have elevated NT-proBNP<sup>3</sup>",
          "id": 3
        }
      ],
      "footnote": "<p><sup>1</sup><em>Decisions about the need for right-heart catheterization should be based on ECHOs obtained at steady state and not during illness such as hospitalization for pain or acute chest syndrome. ECHOs should be repeated in the setting of elevated TRJV prior to referral for right-heart catheterization under the guidance of a PH expert given the suboptimal reproducibility of TRJV measurements</em></p><p><sup>2</sup><em>For patients with an isolated TRJV ≥ 2.5 m/sec who are asymptomatic, other non-invasive evaluation (NT-proBNP or 6MWD) is suggested to increase the diagnostic accuracy for PH.</em></p><p><sup>3</sup><em>Abnormal cutoff values for NT-proBNP and 6MWD have not been firmly determined for patients with SCD. However, NT-proBNP values of ≥ 160 pg/mL and 6MWD < 333 meters represent reasonable thresholds for adults with SCD based on previously published studies in this population. </em></p>"
    },
    "2": {
      "text": "<p>Right-heart catheterization <strong>not suggested</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "3": {
      "text": "<p>Right-heart catheterization <strong>suggested</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    }
  },
  "10": {
    "title": "Second Line Therapies for Adults",
    "firstId": 1,
    "1": {
      "text": "<p>Figure 1. Selection of second-line therapy in adults with ITP should be individualized based on duration of disease and patient values and preferences. Other factors that may influence treatment decisions include frequency of bleeding sufficient to require hospitalization or rescue medication, comorbidities, compliance, medical and social support networks, cost, and availability of treatments. Patient education and shared decision-making is encouraged.</p><p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
      "questions": [
        { "label": "Adult with ITP > 3 months dependent on or unresponsive to corticosteroids",
          "id": 2
        }
      ],
    },
    "2": {
      "text": "<h2>Actions:</h2><p>Assess duration of ITP</p>",
      "questions": [
        { "label": "3-12 months",
          "id": 3
        },
        { "label": ">12 months",
          "id": 4
        }
      ],
    },
    "3": {
      "text": "<h2>Primary Treatment Options:</h2><p>Rituximab, TPO-RA</p><h2>Actions:</h2><p>Assess patient values and preferences</p>",
      "questions": [
        {
          "label": "Patient places a high value on achieving durable response",
          "id": 5
        },
        {
          "label": "Patient places a high value on avoiding long-term medication",
          "id": 6
        }
      ],
      "footnote": "<p><strong>TPO-RA</strong> – thrombopoietin receptor agonist</p><p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "4": {
      "text": "<h2>Primary Treatment Options:</h2><p>Rituximab, Splenectomy, TPO-RA</p><h2>Actions:</h2><p>Assess patient values and preferences</p>",
      "questions": [
        {
          "label": "Patient places a high value on achieving durable response",
          "id": 8
        },
        {
          "label": "Patient places a high value on avoiding long-term medication",
          "id": 9
        },
        {
          "label": "Patient places a high value on avoiding surgery",
          "id": 10
        }
      ],
      "footnote": "<p><strong>TPO-RA</strong> – thrombopoietin receptor agonist</p><p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "5": {
      "text": "<h2>Treatment Option:</h2><p>TPO-RA</p>",
      "footnote": "<p><strong>TPO-RA</strong> – thrombopoietin receptor agonist</p><p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "6": {
      "text": "<h2>Treatment Option:</h2><p>Rituximab</p>",
      "footnote": "<p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "7": {
      "text": "<h2>Treatment Option:</h2><p>Splenectomy</p>",
      "footnote": "<p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "8": {
      "text": "<h2>Treatment Options:</h2><p>Splenectomy, TPO-RA</p><h2>Patient characteristics:</h2>",
      "questions": [
        {
          "label": "Patient places a high value on avoiding surgery",
          "id": 5
        },
        {
          "label": "Patient places a high value on avoiding long-term medication",
          "id": 7
        }
      ],
      "footnote": "<p><strong>TPO-RA</strong> – thrombopoietin receptor agonist</p><p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "9": {
      "text": "<h2>Treatment Options:</h2><p>Rituximab, Splenectomy</p><h2>Patient characteristics:</h2>",
      "questions": [
        {
          "label": "Patient places a high value on avoiding surgery",
          "id": 6
        },
        {
          "label": "Patient places a high value on durable response",
          "id": 7
        }
      ],
      "footnote": "<p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    },
    "10": {
      "text": "<h2>Treatment Options:</h2><p>Rituximab, TPO-RA</p><h2>Patient characteristics:</h2>",
      "questions": [
        {
          "label": "Patient places a high value on achiving durable response",
          "id": 5
        },
        {
          "label": "Patient places a high value on avoiding long-term medication",
          "id": 6
        }
      ],
      "footnote": "<p><strong>TPO-RA</strong> – thrombopoietin receptor agonist</p><p>All recommendations in Figure 1 are conditional recommendations <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>"
    }
  },
  "9": {
    "title": "Inpatient vs. Outpatient Management",
    "firstId": 1,
    "1": {
      "text": "<h2>Platelet Count</h2>",
      "questions": [
        { "label": "Platelet count of <20 x10<sup>9</sup>/l and asymptomatic or minor mucocutaneous bleeding",
          "id": 2
        },
        {
          "label": "Platelet count of ≥20 x10<sup>9</sup>/l and asymptomatic or minor mucocutaneous bleeding",
          "id": 3
        }
      ],
    },
    "2": {
      "text": "<h2>Status</h2>",
      "questions": [
        { "label": "Newly diagnosed",
          "id": 4
        },
        {
          "label": "Established Diagnosis",
          "id": 5
        }
      ],
    },
    "3": {
      "text": "<h2>Status</h2>",
      "questions": [
        { "label": "Newly diagnosed",
          "id": 5
        },
        {
          "label": "Established Diagnosis",
          "id": 5
        }
      ],
    },
    "4": {
      "text": "<h2>Management</h2><p><strong>Inpatient</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "5": {
      "text": "<h2>Management</h2><p><strong>Outpatient</strong><sup>1</sup> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><p><sup>1</sup><em>Patients who are refractory to treatment, those with social concerns, uncertainty about the diagnosis, significant comorbidities with risk of bleeding, and more significant mucosal bleeding may benefit from admission to the hospital. The need for admission is also variable across the range of platelet counts represented here (0-20 x10<sup>9</sup>/l).</em>",
    }
  },
  "8": {
    "title": "Anticoagulation and Delivery Assessment",
    "firstId": 1,
    "1": {
      "text": "<h2>Pregnant woman receiving anticoagulation</h2>",
      "questions": [
        { "label": "Therapeutic anticoagulation",
          "id": 2
        },
        {
          "label": "Prophylactic doses anticoagulation",
          "id": 3
        }
      ],
    },
    "2": {
      "text": "<p>Planned delivery with prior discontinuation of AC therapy<sup>2</sup></p><p><sup>2</sup><em>Conditional recommendation <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a>. Planned delivery is defined as either induction of labor or elective cesarean section as per obstetric indications. Planned delivery does not appear to increase the risk of neonatal or maternal complications.</em></p>",
    },
    "3": {
      "text": "<p>Allow spontaneous labor<sup>3</sup></p><p><sup>3</sup><em>Conditional recommendation <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a>. Allowing spontaneous onset labor may minimize the need for medical intervention in labor. The panel considered that the 12-hour recommended interval between the last dose of standard prophylactic-dose LMWH and placement of an epidural catheter would allow most women receiving standard prophylactic-dose LMWH the option of neuraxial anesthesia, regardless of whether delivery was scheduled or spontaneous. Patients and their caregivers who place a very high priority on access to an epidural may prefer planned delivery. Allowing spontaneous onset of labor may have an impact on access to neuraxial analgesia (epidural analgesia or spinal anesthesia).</em></p>",
    }
  },
  "7": {
    "title": "When to Offer Prophylaxis in the Context of Thrombophilia",
    "firstId": 1,
    "1": {
      "text": "<h2>Family History of VTE</h2>",
      "questions": [
        {
          "label": "Yes",
          "id": 2
        },
        {
          "label": "No",
          "id": 3
        }
      ],
    },
    "2": {
      "text": "<h2>Presentation</h2>",
      "questions": [
        {
          "label": "Heterozygous for factor V Leiden mutation",
          "id": 4
        },
        {
          "label": "Homozygous for factor V Leiden mutation",
          "id": 5
        },
        { "label": "Heterozygous for prothrombin mutation",
          "id": 4
        },
        { "label": "Homozygous for prothrombin mutation",
          "id": 6
        },
        { "label": "Protein C deficiency",
          "id": 8
        },
        { "label": "Protein S deficiency",
          "id": 8
        },
        { "label": "Antithrombin deficiency",
          "id": 9
        },
        { "label": "Combined thrombophilias",
          "id": 5
        }
      ],
    },
    "3": {
      "text": "<h2>Presentation</h2>",
      "questions": [
        {
          "label": "Heterozygous for factor V Leiden mutation",
          "id": 4
        },
        {
          "label": "Homozygous for factor V Leiden mutation",
          "id": 5
        },
        { "label": "Heterozygous for prothrombin mutation",
          "id": 4
        },
        { "label": "Homozygous for prothrombin mutation",
          "id": 7
        },
        { "label": "Protein C deficiency",
          "id": 4
        },
        { "label": "Protein S deficiency",
          "id": 4
        },
        { "label": "Antithrombin deficiency",
          "id": 4
        },
        { "label": "Combined thrombophilias",
          "id": 5
        }
      ],
    },
    "4": {
      "text": "<h2>Antepartum Prophylaxis</h2><p><strong>No</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><h2>Postpartum Prophylaxis</h2><p><strong>No</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "5": {
      "text": "<h2>Antepartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><h2>Postpartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "6": {
      "text": "<h2>Antepartum Prophylaxis</h2><p><strong>Yes</strong><sup>1</sup></p><p><sup>1</sup><em>The ASH guideline panel did not find sufficient evidence to support a formal recommendation or suggestion either for or against antepartum prophylaxis in the context of patients homozygous for prothrombin mutation. The panel consensus was that antepartum prophylaxis is likely appropriate.</em></p><h2>Postpartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "7": {
      "text": "<h2>Antepartum Prophylaxis</h2><p><strong>No</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><h2>Postpartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "8": {
      "text": "<h2>Antepartum Prophylaxis</h2><p><strong>No</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><h2>Postpartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(1)'><span class='rating-1'></span></a></p>",
    },
    "9": {
      "text": "<h2>Antepartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><h2>Postpartum Prophylaxis</h2><p><strong>Yes</strong> <a ng-click='recommendationPopup(1)'><span class='rating-1'></span></a></p>",
    }

  },
  "6": {
    "title": "Prophylaxis for Pregnant Women Not Receiving Long-Term Anticoagulation Therapy",
    "firstId": 1,
    "1": {
      "text": "<p>Patients not on long-term anticoagulant therapy with no thrombophilia</p><h2>History of VTE</h2>",
      "questions": [
        { "label": "Unprovoked VTE or hormonal risk factor<sup>1</sup>",
          "id": 2
        },
        {
          "label": "Temporary nonhormonal provoking risk factor (and no other risk factors)<sup>2</sup>",
          "id": 3
        }
      ],
      "footnote": "<p><em><sup>1</sup> Hormonal risk factors include pregnancy, postpartum, and hormonal contraception associated with increased VTE risk.</em><br><em><sup>2</sup>Temporary nonhormonal provoking risk factors include surgery, trauma, and prolonged immobilization.</em></p>",
    },
    "2": {
      "text": "<h2>Antepartum</h2><p>Antepartum anticoagulation prophylaxis <strong>recommended</strong> <a ng-click='recommendationPopup(1)'><span class='rating-1'></span></a></p><h2>Postpartum</h2><p>Postpartum anticoagulation prophylaxis for all women <a ng-click='recommendationPopup(1)'><span class='rating-1'></span></a></p>",
    },
    "3": {
      "text": "<h2>Antepartum</h2><p>Antepartum anticoagulation prophylaxis <strong>not suggested</strong> <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><h2>Postpartum</h2><p>Postpartum anticoagulation prophylaxis for all women <a ng-click='recommendationPopup(1)'><span class='rating-1'></span></a></p>",
    }
  },
  "5": {
    "title": "Anticoagulation Reversal",
    "firstId": 7,
    "7": {
      "text": "<p><sup>2</sup><em>When deciding between coagulation factor Xa (recombinant), inactivated-zhzo and 4-factor PCC, there was insufficient information available for the ASH guideline panel to recommend one treatment over the other. Coagulation factor Xa (recombinant), inactivated-zhzo adminis- tration in addition to stopping oral direct Xa inhibitors is preferred to stopping oral direct Xa inhibitors alone; whereas the panel suggests no preference for stopping oral direct Xa inhibitors and administering 4-factor PCC over stopping oral direct Xa inhibitors alone.</em></p>",
      "questions": [
        {
          "label": "VKA",
          "id": 8
        },
        {
          "label": "Oral direct Xa inhibitor<sup>2</sup>",
          "id": 3
        },
        {
          "label": "Dabigatran",
          "id": 4
        },
        {
          "label": "Low-molecular weight heparin (LMWH)",
          "id": 5
        },
        {
          "label": "Unfractionated Heparin (UFH)",
          "id": 6
        }
      ]
    },
    "8": {
      "questions": [
        {
          "label": "No clinically relevant bleeding; INR &gt;4.5 but &lt;10",
          "id": 1
        },
        {
          "label": "Life-threatening bleeding; INR Elevated &gt;1.3",
          "id": 2
        }
      ]
    },
    "1": {
      "text": "<h2>Response</h2><p>Temporary cessation of VKA <b>without</b> the addition of vitamin K <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "2": {
      "text": "<h2>Response</h2><p>Stop VKA and administer 4-factor prothrombin complex concentrates (PCCs)<sup>1</sup> <b>and up to 10 mg of</b> IV vitamin K <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><p><sup>1</sup><em>PCCs are suggested for use instead of fresh-frozen plasma (FFP) in the case of life-threatening bleeding associated with VKA anticoagulation due to ease of administration, less risk for volume overload, and other advantages (e.g., viral inactivation).</em></p>",
    },
    "3": {
      "text": "<h2>Bleeding Severity</h2><p>Life-threatening</p><h2>Response</h2><p>Stop oral direct Xa inhibitor alone <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><b>OR</b><p>Stop oral direct Xa inhibitor and administer 4 factor prothrombin complex concentrates (PCCs) <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p><b>VS.</b><p>Stop oral direct Xa inhibitor and administer coagulation factor Xa (recombinant), inactivated-zhzo (if available) <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "4": {
      "text": "<h2>Bleeding Severity</h2><p>Life-threatening</p><h2>Response</h2><p>Stop dabigatran <b>and</b> administer idarucizumab <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "5": {
      "text": "<h2>Bleeding Severity</h2><p>Life-threatening</p><h2>Response</h2><p>Stop LMWH <b>and</b> administer protamine <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
    "6": {
      "text": "<h2>Bleeding Severity</h2><p>Life-threatening</p><h2>Response</h2><p>Stop UFH <b>and</b> administer protamine <a ng-click='recommendationPopup(2)'><span class='rating-conditional'></span></a></p>",
    },
  },
  "4": {
    "title": "VWD Assessment Algorithm",
    "firstId": 50,
    "50": {
      "text": "<p>Positive Initial Screen by History & Physical Exam</p><h2>Initial Hemostasis Tests</h2><ul><li>CBC and platelet count</li><li>PT and PTT</li><li>Fibrinogen or TT (optional)</li></ul><p>If bleeding history is strong, consider performing initial VWD assays</p><p>If other cause identified, e.g., extremely low platelets, isolated abnormal PT, low fibrinogen, abnormal TT, then perform other appropriate evaluations.</p>",
      "questions": [
        {
          "label": "Isolated prolonged PTT that corrects on 1:1 mixing study, or no abnormalities",
          "id": 52
        }
      ]
    },
    "52": {
      "text": "<h2>Initial VWD Assays</h2><ul><li>VWF:Ag</li><li>VWF:RCo</li><li>FVIII</li></ul>",
      "questions": [
        { "label": "Abnormal",
          "id": 53
        },
        {
          "label": "Normal",
          "id": 54
        }
      ]
    },
    "53": {
      "text": "<p>Selected specialized VWD studies such as:</p><ul><li>Repeat initial VWD assays if necessary</li><li>Ratio of VWF:RCo to VWF:Ag</li><li>Multimer distribution</li><li>Collagen binding</li><li>RIPA or platelet binding</li><li>FVIII binding</li><li>Platelet VWF studies</li><li>DNA sequencing of VWF gene</li></ul>"
    },
    "54": {
      "text": "<p>Consider testing such as:</p><ul><li>Factor IX, Factor XI (if PTT prolonged)</li><li>Platelet function testing</li><li>Factor XIII testing</li><li>Evaluation for Ehlers Danlos syndrome</li></ul>"
    }
  },
  "3": {
    "title": "Chronic Warfarin dosing",
    "firstId": 42,
    "42": {
      "text": "<p>This nomogram is suggested for <b>non-bleeding patients</b> with target INR 2.0-3.0 who are out of range and who are not at high risk of bleeding.</p><ol><li>If INR >3.0 confirm no bleeding.</li><li>Consider noncompliance, illness, drug interaction, or dietary change as reason for out-of-range INR.</li><li>Clinical judgment should supersede this nomogram.</li></ol>",
      "questions": [
        {
          "label": "INR < 2.0",
          "id": 43
        },
        {
          "label": "INR 3.1-3.5",
          "id": 44
        },
        {
          "label": "INR 3.6-4.0",
          "id": 45
        },
        {
          "label": "INR 4.1-8.9",
          "id": 46
        },
        {
          "label": "INR > 9.0",
          "id": 47
        }
      ]
    },
    "43": {
      "text": "<p>Increase by 10–15%. Consider 15% increase if INR ≤1.5 without explanation.</p><p>Repeat INR within 1 week.</p>"
    },
    "44": {
      "text": "<p>Decrease by 0–10%</p><p>Repeat INR within 2 weeks.</p>"
    },
    "45": {
      "text": "<p>Hold 0–1 dose, decrease by 10–15%</p><p>Repeat INR within 1 week.</p>"
    },
    "46": {
      "text": "<p>Hold 0–2 doses, decrease by 10–15% +/- Vit. K 2.5 mg po</p><p>Repeat INR in 2 days.</p>"
    },
    "47": {
      "text": "<p>Hold 2 doses decrease by 15–20% Vit. K 2.5–5 mg po</p><p>Repeat INR next day.</p>"
    }
  },
  "2": {
    "title": "Day/INR/Dose",
    "firstId": 17,
    "17": {
      "questions": [
        {
          "label": "Day 1-3",
          "id": 18
        },
        {
          "label": "Day 3 or 4",
          "id": 19
        },
        {
          "label": "7 & 10",
          "id": 20
        }
      ]
    },
    "18": {
      "text": "<h2>INR not required.</h2><p><strong>Daily dose:</strong> 5mg. 2.5 mg for frailty, liver disease, malnutrition, drugs that enhance warfarin activity, or Asian ethnicity; 5-7.5 mg for young healthy patients.</p>"
    },
    "19": {
      "questions": [
        {
          "label": "INR 1.0-1.3",
          "id": 21,
        },
        {
          "label": "INR 1.4-1.5",
          "id": 22,
        },
        {
          "label": "INR 1.6-18",
          "id": 23,
        },
        {
          "label": "INR > 1.9",
          "id": 24,
        },
        {
          "label": "INR >= 2.0",
          "id": 25
        }
      ]
    },
    "20": {
      "questions": [
        {
          "label": "INR <= 1.5",
          "id": 26
        },
        {
          "label": "INR 1.6-1.9",
          "id": 27
        },
        {
          "label": "INR 2.0-3.0",
          "id": 28
        },
        {
          "label": "INR 3.1-3.5",
          "id": 29
        },
        {
          "label": "INR 3.6-4.0",
          "id": 30
        },
        {
          "label": "INR > 4.1",
          "id": 31
        },
        {
          "label": "INR >= 6.0",
          "id": 32
        }
      ]
    },
    "21": {
      "text": "<p><strong>Daily dose:</strong> 7.5 mg</p>"
    },
    "22": {
      "text": "<p><strong>Daily dose:</strong> 5 mg</p>"
    },
    "23": {
      "text": "<p><strong>Daily dose:</strong> 5/2.5 mg alternating</p>"
    },
    "24": {
      "text": "<p><strong>Daily dose:</strong> 2.5 mg</p>"
    },
    "25": {
      "text": "<p><strong>Daily dose:</strong> Hold x 1 day, then 2.5 mg. Check INR more frequently.</p>"
    },
    "26": {
      "text": "<p><strong>Daily dose:</strong> Increase by 15% of ADD</p>"
    },
    "27": {
      "text": "<p><strong>Daily dose:</strong> Increase by 10% of ADD</p>"
    },
    "28": {
      "text": "<p><strong>Daily dose:</strong> No change</p>"
    },
    "29": {
      "text": "<p><strong>Daily dose:</strong> Decrease by 10% of ADD</p>"
    },
    "30": {
      "text": "<p><strong>Daily dose:</strong> Decrease by 15% of ADD</p>"
    },
    "31": {
      "text": "<p><strong>Daily dose:</strong> Hold 1 day, decrease by 15% (or more). Check INR more frequently</p>"
    },
    "32": {
      "text": "<p><strong>Daily dose:</strong> Consider Vitamin K. Check INR more frequently</p>"
    },
  },
  "1": {
    "title": "Diagnostic and Initial Treatment Algorithm",
    "firstId": 2,
    "2": {
      "questions": [
        {
          "label": "Intermediate/high clinical probability (4T score ≥ 4)",
          "id": 3
        },
        {
          "label": "Low clinical probability (4T score ≤ 3)",
          "id": 4
        }
      ]
    },
    "3": {
      "text": "<p>Discontinue heparin; start non-heparin anticoagulant<sup>1</sup></p><p>Obtain immunoassay</p>",
      "questions": [
        {
          "label": "Positive",
          "id": 5
        },
        {
          "label": "Negative",
          "id": 4
        }
      ],
      "footnote": "<p><sup>1</sup> <em>If the patient has an intermediate-probability 4Ts score, has no other indication for therapeutic-intensity anticoagulation, and is judged to be at high risk for bleeding, the panel suggests treatment with a non-heparin anticoagulant at prophylactic intensity rather than therapeutic intensity. If the patient has an intermediate-proba- bility 4Ts score and is not judged to be at high risk for bleeding or has another indication for therapeutic-intensity anticoagulation, the panel suggests treatment with a non-heparin anticoagulant at therapeutic intensity rather than prophylactic intensity. In a patient with a high-probability 4Ts score, the panel recommends treatment with a non-heparin anticoagulant at therapeutic intensity.</em></p>"
    },
    "4": {
      "text": "<h2>HIT unlikely</h2><p>Do not order HIT lab testing; Continue/resume heparin if indicated; Discontinue non-heparin anticoagulant (if applicable)</p>"
    },
    "5": {
      "text": "<p>Continue to avoid heparin; Continue non-heparin anticoagulant<sup>2</sup></p><p>Obtain functional assay<sup>3</sup></p>",
      "questions": [
        {
          "label": "Positive",
          "id": 6
        },
        {
          "label": "Negative<sup>4</sup>",
          "id": 4
        }
      ],
      "footnote": "<p><sup>2</sup> <em>For all intermediate/high probability patients with a positive immunoassay, including those who were receiving prophylactic-intensity treatment with a non-heparin anticoagulant prior to the availability of the immunoassay result, the panel recommends treatment with a non-heparin anticoagulant at therapeutic intensity.</em></p><p><sup>3</sup> <em>In some settings, a functional assay may not be available and decisions may need to be made based on the results of the 4Ts and immunoassay. A functional assay may not be necessary in patients with a high 4Ts score and a strongly positive immunoassay (e.g., an ELISA > 2.0 optical density units).</em></p><p><sup>4</sup> <em>Most patients with a negative functional assay do not have HIT and may be managed accordingly. However, depending on the type of functional assay and the technical expertise of the laboratory, false-negative results are possible. Therefore, a presumptive diagnosis of HIT may be considered for some patients with a negative functional assay, especially if there is a high-probability 4Ts score and a strongly positive immunoassay. This is represented in the figure by a dashed line.</em></p>"
    },
    "6": {
      "text": "<h2>HIT Likely</h2><p>See 'Treatment' section for management recommendations</p>"
    }
  }
};
