var hemoServices = angular.module('hemo.services', ['angular-cache']);

hemoServices
.factory('DataLoader', function($http, CacheFactory, CMS_ENDPOINT, WHICH_CMS) {
  CacheFactory('dataCache', {
    storageMode: 'localStorage'
  });

  // TODO build in a random delay here to prevent the thundering herd problem. Will want an idea
  // of how many requests / sec our CMS can field, vs. an upper bound on how many new installs
  // we'd expect, which is probably 30 or 40k)
  var fetchData = function() {
    var dataCache = CacheFactory.get('dataCache');
    var url = CMS_ENDPOINT + "data/all.json";

    // show all guides, including those with the "is_staging" bool set
    if ("staging" == WHICH_CMS || "development" == WHICH_CMS) {
      url += "?staging=1";
    }
    
    $http.get(url).success(function(data, status, headers, config) {
      data.savedAt = new Date().valueOf();
      dataCache.put('all', data);
    });
  };

  return function(successCallback) {
    var dataCache = CacheFactory.get('dataCache');

    if (dataCache.get('all') && dataCache.get('all')['homepage_items']) {
      // we have data in localStorage, and it knows about the dynamic homepage patch
      var data = successCallback(dataCache.get('all'));
      if ("production" == WHICH_CMS) {
        var cacheMaxAge = 4 * 60 * 60 * 1000; // 4 hours
        var cacheAge = new Date() - new Date(data.savedAt);
        if (cacheAge > cacheMaxAge) {
          fetchData();
        }
      } else {
        fetchData();
      }
    } else {
      // fetch from filesystem
      var url = "data/all.json";
      $http.get(url).then(successCallback);
      fetchData();
    }
  };
})

// inject all calculator data objs here.
// calc data can be found in js/calculator_data.js
.factory('Calculator', function(CalcDataPe, CalcDataDvt, CalcDataBleedingScore, CalcData4ts, CalcDataHCTCI, CalcDataIpss) {
  return {
    questionNumber: null,
    data: null,
    init: function(dataFactoryName) {
      this.data = eval(dataFactoryName);
      this.questionNumber = -1;
      
      return this;
    },
    goToQuestion: function(qNum) {
      this.questionNumber = qNum;
    },
    isIntroPage: function() {
      return this.questionNumber == -1;
    },
    isFinished: function() {
      return this.questionNumber == this.data.questions.length;
    },
    chooseOption: function(index) {
      if (this.data.type == "checkbox") {
        this._chooseOptionCheckbox(index);
      } else if (this.data.type == "radio") {
        this._chooseOptionRadio(index);
      }
    },
    _chooseOptionCheckbox: function(index) {
      this.data.questions[this.questionNumber].options[index].isSelected =
        ! this.data.questions[this.questionNumber].options[index].isSelected;
    },
    _chooseOptionRadio: function(index) {
      angular.forEach(this.data.questions[this.questionNumber].options, function(option, optIndex) {
        option.isSelected = false;
      });
      
      this.data.questions[this.questionNumber].options[index].isSelected = true;
    },    
    answerQuestion: function() {
      // add up all options where isSelected == true
      var questionTotal = this.data.questions[this.questionNumber].options.filter(function(opt) {
        return (opt.isSelected);
      }).reduce(function(total, opt) {
        return total + opt.value;
      }, 0);

      this.data.questions[this.questionNumber].total = (this.questionNumber == 0) ? questionTotal : this.data.questions[this.questionNumber - 1].total + questionTotal;
    },
    hasAnswer: function() {
      if (this.questionNumber < 0 || this.isFinished()) {
        return false;
      }

      if (this.data.type == "checkbox") {
        // don't need to select anything
        return true;
      }

      var found = false;
      angular.forEach(this.data.questions[this.questionNumber].options, function(value, index) {
        if (value.isSelected) {
          found = true;
        }
      });

      return found;
    },
    // returns: { level: "low", rangeDescription: "description of range" }
    getRange: function() {
      var t = this;
      var range;
      var found = false;
      angular.forEach(this.data.rangeThresholds, function(value, index) {
        var level = Object.keys(value)[0];        
        if (t.getTotal() < level && !found) {
          var levelClass = value[level];
          range = { level: level, levelClass: levelClass, rangeDescription: t.data.rangeDescriptions[t.data.rangeThresholds[index][parseFloat(level)]] };
          found = true; //yeah...you can't use break...
        }
      });

      return range;
    },
    getTotal: function() {
      var question = this.data.questions[this.questionNumber - 1];
      if (typeof(question) != "undefined") {
        return question.total;
      } else {
        return 0;
      }
    },
    reset: function() {
      this.questionNumber = -1;
      var t = this;
      angular.forEach(this.data.questions, function(question, qIndex) {
        question.total = 0;
        angular.forEach(question.options, function(option, optIndex) {
          option.isSelected = false;
        });
      });
    }
  };
})

.factory('OnePageCheckboxCalculator', function(CalcDataDvt) {
  return {
    questionNumber: null,
    data: null,
    init: function(dataFactoryName) {
      this.data = eval(dataFactoryName);
      this.questionNumber = -1;
      
      return this;
    },
    goToQuestion: function(qNum) {
      this.questionNumber = qNum;
    },
    isIntroPage: function() {
      return this.questionNumber == -1;
    },
    chooseOption: function(index) {
      this.data.questions[this.questionNumber].options[index].isSelected =
        ! this.data.questions[this.questionNumber].options[index].isSelected;

      this.answerQuestion();
    },
    answerQuestion: function() {
      // add up all options where isSelected == true
      var questionTotal = this.data.questions[this.questionNumber].options.filter(function(opt) {
        return (opt.isSelected);
      }).reduce(function(total, opt) {
        return total + opt.value;
      }, 0);

      this.data.questions[this.questionNumber].total = questionTotal;
    },
    // returns: { level: "low", rangeDescription: "description of range" }
    getRange: function() {
      var t = this;
      var range;
      var found = false;
      angular.forEach(this.data.rangeThresholds, function(value, index) {
        var level = Object.keys(value)[0];
        if (t.getTotal() < level && !found) {
          range = { level: level, rangeDescription: t.data.rangeDescriptions[t.data.rangeThresholds[index][parseInt(level)]] };
          found = true; //yeah...you can't use break...
        }
      });

      return range;
    },
    getTotal: function() {
      var question = this.data.questions[this.questionNumber];
      if (typeof(question) != "undefined") {
        return question.total;
      } else {
        return 0;
      }
    },
    getName: function() {
      return (this.data.short_name) ? this.data.short_name : this.data.name;
    },
    reset: function() {
      this.questionNumber = -1;
      var t = this;
      angular.forEach(this.data.questions, function(question, qIndex) {
        question.total = 0;
        angular.forEach(question.options, function(option, optIndex) {
          option.isSelected = false;
        });
      });
    }
  };
})

.factory('HCTCICalc', function(Calculator) {
  return {
    questionNumber: Calculator.questionNumber,
    data: Calculator.data,
    init: Calculator.init,
    goToQuestion: Calculator.goToQuestion,
    isIntroPage: Calculator.isIntroPage,
    isFinished: Calculator.isFinished,
    chooseOption: Calculator.chooseOption,
    _chooseOptionCheckbox: Calculator._chooseOptionCheckbox,
    _chooseOptionRadio: Calculator._chooseOptionRadio,
    answerQuestion: Calculator.answerQuestion,
    hasAnswer: Calculator.hasAnswer,
    getRange: Calculator.getRange,
    getTotal: Calculator.getTotal,
    reset: Calculator.reset,

    getPreAgeTotal: function() {
      var question = this.data.questions[this.questionNumber - 2];
      if (typeof(question) != "undefined") {
        return question.total;
      } else {
        return 0;
      }
    },

    getPreAgeRange: function() {
      var t = this;
      var range;
      var found = false;
      angular.forEach(this.data.rangeThresholds, function(value, index) {
        var level = Object.keys(value)[0];
        if (t.getPreAgeTotal() < level && !found) {
          var levelClass = value[level];
          range = { level: level, levelClass: levelClass, rangeDescription: t.data.rangeDescriptions[t.data.rangeThresholds[index][parseInt(level)]] };
          found = true;
        }
      });

      return range;
    }
  }
})

.factory('IpssrData', function() {
  return {
    slug: "ipssr?page=0"
  };
})

.factory('IpssrCalc', function(IpssrData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    validForRange: function(val, min, max) {
      return (this.isNumeric(val) && val >= min && val <= max);
    },
    calculate: function() {
      IpssrData.score = 0;

      // hemoglobin
      var val = IpssrData.hemoglobin;
      if (val < 8) {
        IpssrData.score += 1.5;
      } else if (val < 10) {
        IpssrData.score += 1;
      }

      // absolute neutrophil count
      val = IpssrData.anc;
      if (val < 0.8) {
        IpssrData.score += 0.5;
      }

      // platelets
      val = IpssrData.platelets;
      if (val < 50) {
        IpssrData.score += 1;
      } else if (val < 100) {
        IpssrData.score += 0.5;
      } 
      
      // bone marrow blasts
      val = IpssrData.bmb;
      if (val > 10) {
        IpssrData.score += 3;
      } else if (val >= 5) {
        IpssrData.score += 2;
      } else if (val > 2) {
        IpssrData.score += 1;
      }

      // cytogenetic category
      IpssrData.score += parseInt(IpssrData.cyto);

      // age adjustment
      if (IpssrData.age) {
        var ageAdjustment = (parseInt(IpssrData.age) - 70) * (0.05 - (IpssrData.score * 0.005));
        IpssrData.score += ageAdjustment;
        IpssrData.score = +IpssrData.score.toFixed(2);
      }

      this.setResultDescription();
    },
    setResultDescription: function() {
      if (IpssrData.score <= 1.5) {
        IpssrData.resultDescription = "very low";
      } else if (IpssrData.score <= 3) {
        IpssrData.resultDescription = "low";
      } else if (IpssrData.score <= 4.5) {
        IpssrData.resultDescription = "intermediate";
      } else if (IpssrData.score <= 6) {
        IpssrData.resultDescription = "high";
      } else {
        IpssrData.resultDescription = "very high";
      }
    },
    validate: function() {
      if (!this.validForRange(IpssrData.hemoglobin, 4, 20)) {
        return "Hemoglobin: Please enter a value between 4 and 20"; 
      }

      if (!this.validForRange(IpssrData.anc, 0, 15)) {
        return "Absolute Neutrophil Count: Please enter a value between 0 and 15"; 
      }

      if (!this.validForRange(IpssrData.platelets, 0, 2000)) {
        return "Platelets: Please enter a value between 0 and 2000"; 
      }

      if (!this.validForRange(IpssrData.bmb, 0, 30)) {
        return "Bone Marrow Blasts: Please enter a value between 0 and 30"; 
      }

      if (!this.isNumeric(IpssrData.cyto)) {
        return "Please select a cytogenic category";
      }

      if (IpssrData.age && !this.isNumeric(IpssrData.age)) {
        return "please enter a valid age";
      }
      
      return false;
    },
    reset: function() {
      IpssrData.hemoglobin        = null;
      IpssrData.anc               = null;
      IpssrData.platelets         = null;
      IpssrData.bmb               = null;
      IpssrData.cyto              = null;
      IpssrData.age               = null;
      IpssrData.resultDescription = null;
    }
  };
})

.factory('MyelomaFrailtyData', function() {
  return {
    slug: "myelomafrailty?page=0",
    questions: {
      charlson: {
        checkboxes: [
          {
            label: "AIDS",
            value: 6,
            isSelected: false
          },
          {
            label: "Cerebrovascular disease",
            value: 1,
            isSelected: false
          },
          {
            label: "Chronic pulmonary disease",
            value: 1,
            isSelected: false
          },
          {
            label: "Congestive heart failure",
            value: 1,
            isSelected: false
          },
          {
            label: "Connective tissue disease",
            value: 1,
            isSelected: false
          },
          {
            label: "Dementia",
            value: 1,
            isSelected: false
          },
          {
            label: "Hemiplegia",
            value: 2,
            isSelected: false
          },
          {
            label: "Leukemia",
            value: 2,
            isSelected: false
          },
          {
            label: "Malignant lymphoma",
            value: 2,
            isSelected: false
          },
          {
            label: "Myocardial infarction",
            value: 1,
            isSelected: false
          },
          {
            label: "Peripheral vascular disease",
            value: 1,
            isSelected: false
          },
          {
            label: "Ulcer disease",
            value: 1,
            isSelected: false
          }
        ],
        diabetes: "0",
        liverDisease: "0",
        renalDisease: "0",
        mst: "0"
      },
      badl: {
        checkboxes: [
          {
            label: "Bathing (sponge bath, tub bath, or shower)",
            description: "Receives either no assistance or assistance in bathing only one part of body", 
            value: 1,
            isSelected: true
          },
          {
            label: "Dressing",
            description: "Gets clothes and dresses without any assistance except for tying shoes.",
            value: 1,
            isSelected: true
          },
          {
            label: "Toileting",
            description: "Goes to toilet room, uses toilet, arranges clothes, and returns without any assistance (may use cane or walker for support and may use bedpan/urinal at night",
            value: 1,
            isSelected: true
          },
          {
            label: "Transferring",
            description: "Moves in and out of bed and chair without assistance (may use cane or walker)",
            value: 1,
            isSelected: true
          },
          {
            label: "Continence",
            description: "Controls bowel and bladder completely by self (without occasional \"accidents\")",
            value: 1,
            isSelected: true
          },
          {
            label: "Feeding",
            description: "Feeds self without assistance (except for help with cutting meat or buttering bread)",
            value: 1,
            isSelected: true
          }
        ]
      },
      iadl: {
        phone: "0",
        shopping: "0",
        food: "0",
        housekeeping: "0",
        laundry: "0",
        transport: "0",
        medications: "0",
        finances: "0"
      }
    }
  };
})

.factory('MyelomaFrailtyCalc', function(MyelomaFrailtyData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    validForRange: function(val, min, max) {
      return (this.isNumeric(val) && val >= min && val <= max);
    },
    chooseOption: function(section, index) {
      MyelomaFrailtyData.questions[section].checkboxes[index].isSelected = !MyelomaFrailtyData.questions[section].checkboxes[index].isSelected;
    },
    calculate: function() {
      var scoreCharlson = this.calculateCharlson();
      var scoreBADL = this.calculateBADL();
      var scoreIADL = this.calculateIADL();

      var finalScore = 0;

      if (MyelomaFrailtyData.age > 80) {
        finalScore += 2;
      } else if (MyelomaFrailtyData.age >= 76 && MyelomaFrailtyData.age <= 80) {
        finalScore += 1;
      }

      if (scoreCharlson >= 2) {
        finalScore += 1;
      }

      if (scoreBADL <= 4) {
        finalScore += 1;
      }

      if (scoreIADL <= 5) {
        finalScore += 1;
      }
      
      MyelomaFrailtyData.score = finalScore;
            
      this.setResultDescription();
    },
    calculateCharlson: function() {
      var score = 0;

      angular.forEach(MyelomaFrailtyData.questions.charlson.checkboxes, function(option, optIndex) {
        if (option.isSelected) {
          score += option.value;
        }
      });

      if (MyelomaFrailtyData.questions.charlson.diabetes == "1") {
        score += 1;
      } else if (MyelomaFrailtyData.questions.charlson.diabetes == "2") {
        score += 2;
      }

      var liver = parseInt(MyelomaFrailtyData.questions.charlson.liverDisease);
      if (liver == 1) {
        score += 1;
      } else if (liver > 1) {
        score += 3;
      }

      var renal = parseInt(MyelomaFrailtyData.questions.charlson.renalDisease);
      if (renal == 1) {
        score += 1;
      } else if (renal > 1) {
        score += 2;
      }

      if (MyelomaFrailtyData.questions.charlson.mst == "1") {
        score += 2;
      } else if (MyelomaFrailtyData.questions.charlson.mst == "2") {
        score += 6;
      }

      return score;
    },
    calculateBADL: function() {
      var score = 0;

      angular.forEach(MyelomaFrailtyData.questions.badl.checkboxes, function(option, optIndex) {
        if (option.isSelected) {
          score += option.value;
        }
      });

      return score;
    },
    calculateIADL: function() {
      var score = 0;

      if (MyelomaFrailtyData.questions.iadl.phone != "3") {
        score += 1;
      }

      if (MyelomaFrailtyData.questions.iadl.shopping == "0") {
        score += 1;
      }

      if (MyelomaFrailtyData.questions.iadl.food == "0") {
        score += 1;
      }

      if (MyelomaFrailtyData.questions.iadl.housekeeping != "4") {
        score += 1;
      }

      if (MyelomaFrailtyData.questions.iadl.laundry != "2") {
        score += 1;
      }

      if (parseInt(MyelomaFrailtyData.questions.iadl.transport) < 3) {
        score += 1;
      }

      if (MyelomaFrailtyData.questions.iadl.medications == "0") {
        score += 1;
      }

      if (MyelomaFrailtyData.questions.iadl.finances != "2") {
        score += 1;
      }
      
      return score;
    },
    setResultDescription: function() {
      if (MyelomaFrailtyData.score >= 2) {
        MyelomaFrailtyData.resultDescription = "frail"
      } else if (MyelomaFrailtyData.score == 1) {
        MyelomaFrailtyData.resultDescription = "unfit"
      } else {
        MyelomaFrailtyData.resultDescription = "fit"
      }
    },
    validate: function() {
      if (!MyelomaFrailtyData.age || !this.isNumeric(MyelomaFrailtyData.age)) {
        return "please enter a valid age";
      }
            
      return false;
    },
    reset: function() {
      angular.forEach(MyelomaFrailtyData.questions.charlson.checkboxes, function(option, optIndex) {
        option.isSelected = false;
      });

      MyelomaFrailtyData.questions.charlson.diabetes = "0";
      MyelomaFrailtyData.questions.charlson.liverDisease = "0";
      MyelomaFrailtyData.questions.charlson.renalDisease = "0";
      MyelomaFrailtyData.questions.charlson.mst = "0";

      angular.forEach(MyelomaFrailtyData.questions.badl.checkboxes, function(option, optIndex) {
        option.isSelected = true;
      });

      MyelomaFrailtyData.questions.iadl.phone = "0";
      MyelomaFrailtyData.questions.iadl.shopping = "0";
      MyelomaFrailtyData.questions.iadl.food = "0";
      MyelomaFrailtyData.questions.iadl.housekeeping = "0";
      MyelomaFrailtyData.questions.iadl.laundry = "0";
      MyelomaFrailtyData.questions.iadl.transport = "0";
      MyelomaFrailtyData.questions.iadl.medications = "0";
      MyelomaFrailtyData.questions.iadl.finances = "0";

      MyelomaFrailtyData.age = null;
    }
  };
})

.factory('CreatinineClearanceData', function() {
  return {
    slug: "creatinine?page=0"
  };
})

.factory('CreatinineClearanceCalc', function(CreatinineClearanceData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      CreatinineClearanceData.score = 0;

      var sex        = CreatinineClearanceData.sex;
      var weightUnit = CreatinineClearanceData.weightUnit;
      var weight     = parseFloat(CreatinineClearanceData.weight);
      var age        = parseInt(CreatinineClearanceData.age);
      var serum      = parseFloat(CreatinineClearanceData.serumCreatinine);

      // [[140 - age(yr)]*weight(kg)]/[72*serum Cr(mg/dL)]  (multiply by 0.85 for women).

      if (weightUnit == "lbs") {
        weight = weight * 0.45359237;
      }
      
      CreatinineClearanceData.score = ((140 - age) * weight) /
        (72 * serum);

      if (sex == "F") {
        CreatinineClearanceData.score = CreatinineClearanceData.score * 0.85;
      }

      CreatinineClearanceData.score = CreatinineClearanceData.score.toFixed(2);
    },
    validate: function() {
      if (!this.isNumeric(CreatinineClearanceData.weight)) {
        return "please enter a valid weight";
      }

      if (!this.isNumeric(CreatinineClearanceData.age)) {
        return "please enter a valid age";
      }

      if (!this.isNumeric(CreatinineClearanceData.serumCreatinine)) {
        return "please enter a valid serum creatinine amount";
      }
      
      return false;
    },
    reset: function() {
      CreatinineClearanceData.sex             = null;      
      CreatinineClearanceData.age             = null;
      CreatinineClearanceData.weightUnit      = null;      
      CreatinineClearanceData.weight          = null;      
      CreatinineClearanceData.serumCreatinine = null;
    }
  };
})

.factory('MipiData', function() {
  return {
    slug: "mipi?page=0"
  };
})

.factory('MipiCalc', function(MipiData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      MipiData.score = 0;

      var age      = parseInt(MipiData.age);
      var ldh      = parseInt(MipiData.ldh);
      var ldhUpper = parseInt(MipiData.ldhUpper);
      var ecog     = MipiData.ecog;
      var wbc      = parseInt(MipiData.wbc);

      // MipiData.score = [0.03535 × Age (years)] + 0.6978 (if ECOG 2-4) + [1.367 × log10(LDH/ULN)] + [0.9393 × log10(WBC)]
      MipiData.score = (0.03535 * age) + (1.367 * Math.log(ldh/ldhUpper) / Math.log(10)) + (0.9393 * Math.log(wbc * 1000) / Math.log(10));

      if (ecog == "2-4") {
        MipiData.score = MipiData.score + 0.6978;
      }
      
      MipiData.score = MipiData.score.toFixed(1);

      this.setResultDescription();
    },
    setResultDescription: function() {
      if (MipiData.score < 5.7) {
        MipiData.resultDescription = "low";
      } else if (MipiData.score < 6.2) {
        MipiData.resultDescription = "intermediate";
      } else {
        MipiData.resultDescription = "high";
      }
    },    
    validate: function() {
      if (!this.isNumeric(MipiData.age)) {
        return "please enter a valid age";
      }

      if (!this.isNumeric(MipiData.ldh)) {
        return "please enter a valid LDH value";
      }

      if (!this.isNumeric(MipiData.ldhUpper)) {
        return "please enter a valid LDH Upper Limit Normal value";
      }

      if (!this.isNumeric(MipiData.wbc)) {
        return "please enter a valid value for White Blood Cells";
      }
      
      return false;
    },
    reset: function() {
      MipiData.age             = null;
      MipiData.ldh             = null;
      MipiData.ldhUpper        = null;
      MipiData.ecog            = null;
      MipiData.wbc             = null;
    }
  };
})

.factory('IronData', function() {
  return {
    slug: "iron?page=0"
  };
})

.factory('IronCalc', function(IronData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      IronData.score = 0;

      var ageFactor  = IronData.ageFactor;
      var weight     = parseInt(IronData.weight);
      var weightUnit = IronData.weightUnit;
      var hgb        = parseFloat(IronData.hgb);

      if (weightUnit == "kg") {
        weight = weight * 2.20462;
      }
      
      // IronData.score =  0.3 * Weight * (100 - (Hgb * 100) / AgeFactor)
      IronData.score = 0.3 * weight * (100 - (hgb * 100) / ageFactor);
      
      IronData.score = IronData.score.toFixed(2);
    },
    validate: function() {
      if (!this.isNumeric(IronData.weight)) {
        return "please enter a valid weight";
      }

      if (!this.isNumeric(IronData.hgb)) {
        return "please enter a valid Hgb value";
      }
      
      return false;
    },
    reset: function() {
      IronData.ageFactor  = null;
      IronData.weight     = null;
      IronData.weightUnit = null; 
      IronData.hgb        = null;
    }
  };
})

.factory('FactorViiiData', function() {
  return {
    slug: "factorviii?page=0"
  };
})

.factory('FactorViiiCalc', function(FactorViiiData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      FactorViiiData.score = 0;

      var weight     = parseFloat(FactorViiiData.weight);
      var weightUnit = FactorViiiData.weightUnit;
      var inc        = parseFloat(FactorViiiData.inc);

      if (weightUnit == "lbs") {
        weight = weight * 0.45359237;
      }
      
      // FactorViiiData.score = Body Weight (kg) × Desired Factor VIII Increase (IU/dL) × 0.5 (IU/kg per IU/dL)
      FactorViiiData.score = weight * inc * 0.5;
      FactorViiiData.score = FactorViiiData.score.toFixed(0);
    },
    validate: function() {
      if (!this.isNumeric(FactorViiiData.weight)) {
        return "please enter a valid weight";
      }

      if (!this.isNumeric(FactorViiiData.inc)) {
        return "please enter a valid factor increase value";
      }
      
      return false;
    },
    reset: function() {
      FactorViiiData.weightUnit = null;
      FactorViiiData.weight     = null;
      FactorViiiData.inc        = null;
    }
  };
})

.factory('FactorIxData', function() {
  return {
    slug: "factorix?page=0"
  };
})

.factory('FactorIxCalc', function(FactorIxData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      FactorIxData.score = 0;

      var weight     = parseFloat(FactorIxData.weight);
      var weightUnit = FactorIxData.weightUnit;
      var inc        = parseFloat(FactorIxData.inc);

      if (weightUnit == "lbs") {
        weight = weight * 0.45359237;
      }
      
      // FactorIxData.score = Body Weight (kg) × Desired Factor VIII Increase (IU/dL) × 1 (IU/kg)
      FactorIxData.score = weight * inc;
      FactorIxData.score = FactorIxData.score.toFixed(0);
    },
    validate: function() {
      if (!this.isNumeric(FactorIxData.weight)) {
        return "please enter a valid weight";
      }

      if (!this.isNumeric(FactorIxData.inc)) {
        return "please enter a valid factor increase value";
      }
      
      return false;
    },
    reset: function() {
      FactorIxData.weightUnit = null;
      FactorIxData.weight     = null;
      FactorIxData.inc        = null;
    }
  };
})

.factory('RedCellExchangeData', function() {
  return {
    slug: "red_cell_exchange?page=0"
  };
})

.factory('RedCellExchangeCalc', function(RedCellExchangeData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      RedCellExchangeData.score = 0;

      var weight   = parseInt(RedCellExchangeData.weight);
      var height   = parseFloat(RedCellExchangeData.height);
      var hctStart = parseFloat(RedCellExchangeData.hctStart);
      var hctEnd   = parseFloat(RedCellExchangeData.hctEnd);
      var fcr      = parseFloat(RedCellExchangeData.fcr);

      var hrep = 60;
      var weightKg = weight / 2.2;
      var heightCM = Math.pow((height * 2.54 / 100), 3);
      
      var tbv = 183 + (356 * heightCM) + (33.1 * weightKg);
      var rcv = tbv * hctStart / 100;
      var plasmaVol = 2382;
      var a = (hctEnd - hctStart) / hrep;
      var b = (hctStart + hctEnd) / (2 * hrep);
      var c = hctStart / (hctEnd * fcr);
      
      RedCellExchangeData.score = tbv * (a + b * Math.log(c));
      
      RedCellExchangeData.score = RedCellExchangeData.score.toFixed(0);
    },
    validate: function() {
      if (!this.isNumeric(RedCellExchangeData.weight)) {
        return "please enter a valid weight";
      }

      if (!this.isNumeric(RedCellExchangeData.height)) {
        return "please enter a valid height";
      }

      if (!this.isNumeric(RedCellExchangeData.hctStart)) {
        return "please enter a valid HCT Start value";
      }

      if (!this.isNumeric(RedCellExchangeData.hctEnd)) {
        return "please enter a valid Desired HCT End value";
      }

      if (!this.isNumeric(RedCellExchangeData.fcr)) {
        return "please enter a valid FCR value";
      }
      
      return false;
    },
    reset: function() {
      RedCellExchangeData.weight   = null;
      RedCellExchangeData.height   = null;
      RedCellExchangeData.hctStart = null;
      RedCellExchangeData.hctEnd   = null;
      RedCellExchangeData.fcr      = null;
    }
  };
})

.factory('SokalData', function() {
  return {
    slug: "sokal?page=0"
  };
})

.factory('SokalCalc', function(SokalData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      SokalData.score = 0;

      var age           = parseInt(SokalData.age);
      var spleenSize    = parseFloat(SokalData.spleenSize);
      var plateletCount = parseFloat(SokalData.plateletCount);
      var myeloblasts   = parseFloat(SokalData.myeloblasts);

      // Sokal Score = Exp (0.0116 x (Age in years – 43.4)) + (0.0345 x (Spleen size in cm – 7.51)) + (0.188 x ((Platelets in 109/L / 700)2 – 0.563)) + (0.0887 x (blasts in % – 2.10))
      SokalData.score = (0.0116 * (age - 43.4)) +
        (0.0345 * (spleenSize - 7.51)) +
        (0.188 * (Math.pow((plateletCount / 700.0), 2) - 0.563)) +
        (0.0887 * ((myeloblasts / 100) - 2.1));
      SokalData.score = Math.pow(2.718281828, SokalData.score); // = exp(SokalData.score)
      SokalData.score = SokalData.score.toFixed(2);

      this.setResultDescription();
    },
    setResultDescription: function() {
      if (SokalData.score < 0.8) {
        SokalData.resultDescription = "low";
      } else if (SokalData.score <= 1.2) {
        SokalData.resultDescription = "intermediate";
      } else {
        SokalData.resultDescription = "high";
      }
    },
    validate: function() {
      if (!this.isNumeric(SokalData.age)) {
        return "please enter a valid age";
      }

      if (!this.isNumeric(SokalData.spleenSize)) {
        return "please enter a valid spleen size";
      }

      if (!this.isNumeric(SokalData.plateletCount)) {
        return "please enter a valid platelet count";
      }

      if (!this.isNumeric(SokalData.myeloblasts)) {
        return "please enter a valid myeloblast percentage";
      }
      
      return false;
    },
    reset: function() {
      SokalData.age           = null;
      SokalData.spleenSize    = null;
      SokalData.plateletCount = null;
      SokalData.myeloblasts   = null;
    }
  };
})

.factory('EutosData', function() {
  return {
    slug: "Eutos?page=0"
  };
})

.factory('EutosCalc', function(EutosData) {
  return {
    isNumeric: function(n) {
      return !isNaN(parseFloat(n)) && isFinite(n);
    },
    calculate: function() {
      EutosData.score = 0;
      
      var spleenSize = parseFloat(EutosData.spleen);
      var bb         = parseFloat(EutosData.bb);

      EutosData.score = 7 * bb + 4 * spleenSize;
      
      // probability: exp(−2.1007 + 0.0700 × basophils + 0.0402 × spleen size)/(1 + exp[−2.1007 + 0.0700 + basophils + 0.0402 × spleen size])
      var factor = -2.1007 + 0.07 * bb + 0.0402 * spleenSize;
      EutosData.probabilityScore = Math.pow(2.718281828, factor) / (1 + Math.pow(2.718281828, factor));
      EutosData.probabilityScore = EutosData.probabilityScore.toFixed(2);
      
      this.setResultDescription();
    },
    setResultDescription: function() {
      if (EutosData.score <= 87 ) {
        EutosData.resultDescription = "low";
      } else {
        EutosData.resultDescription = "high";
      }
    },
    validate: function() {
      if (!this.isNumeric(EutosData.spleen)) {
        return "please enter a valid spleen size";
      }

      if (!this.isNumeric(EutosData.bb)) {
        return "please enter a valid value for Blood Basophils";
      }
      
      return false;
    },
    reset: function() {
      EutosData.spleen = null;
      EutosData.bb     = null;
    }
  };
})

.factory('$localstorage', ['$window', function($window) {
    return {
        set: function(key, value) {
            $window.localStorage[key] = value;
        },
        get: function(key, defaultValue) {
            return $window.localStorage[key] || defaultValue;
        },
        setObject: function(key, value) {
            $window.localStorage[key] = JSON.stringify(value);
        },
        getObject: function(key) {
            return JSON.parse($window.localStorage[key] || '{}');
        }
    }
}])

.factory('CalcFavoriteable', function($localstorage) {
  return {
    favorites: null,
    init: function() {
      var f = $localstorage.getObject('favorites');
      if (!f.tools) {
        f.tools = [];
        $localstorage.setObject('favorites', f);
      }
      this.favorites = f;
    },
    isFavorited: function(key) {
      return this.favorites.tools.indexOf(key) > -1;
    },
    toggle: function(scope, key) {
      scope.favorited = !scope.favorited;
      if (scope.favorited) {
        this.favorites.tools.push(key);
      } else {
        var i = this.favorites.tools.indexOf(key);
        if (i > -1) {
          this.favorites.tools.splice(i, 1);
        }
      }
      
      $localstorage.setObject('favorites', this.favorites);
    }
  };
});
